@@ -1,9 +1,10 @@
 import { createContext, ReactNode, useCallback, useContext, useEffect, useState, useMemo } from 'react';
-import { useLocalStorage } from 'react-use';
+import { useAsync, useLocalStorage } from 'react-use';
 
 import { PluginExtensionPoints, store } from '@grafana/data';
 import { getAppEvents, reportInteraction, usePluginLinks, locationService } from '@grafana/runtime';
-import { ExtensionPointPluginMeta, getExtensionPointPluginMeta } from 'app/features/plugins/extensions/utils';
+import { ExtensionPointPluginMeta } from 'app/features/plugins/extensions/appUtils';
+import { getExtensionPointPluginMeta } from 'app/features/plugins/extensions/utils';
 import { CloseExtensionSidebarEvent, OpenExtensionSidebarEvent, ToggleExtensionSidebarEvent } from 'app/types/events';
 
 import { DEFAULT_EXTENSION_SIDEBAR_WIDTH, MAX_EXTENSION_SIDEBAR_WIDTH } from './ExtensionSidebar';
@@ -11,13 +12,13 @@ import { DEFAULT_EXTENSION_SIDEBAR_WIDTH, MAX_EXTENSION_SIDEBAR_WIDTH } from './
 export const EXTENSION_SIDEBAR_DOCKED_LOCAL_STORAGE_KEY = 'grafana.navigation.extensionSidebarDocked';
 export const EXTENSION_SIDEBAR_WIDTH_LOCAL_STORAGE_KEY = 'grafana.navigation.extensionSidebarWidth';
 const PERMITTED_EXTENSION_SIDEBAR_PLUGINS = [
-  'grafana-investigations-app',
   'grafana-assistant-app',
   'grafana-dash-app',
   // The docs plugin ID is transitioning from grafana-grafanadocsplugin-app to grafana-pathfinder-app.
   // Support both until that migration is complete.
   'grafana-grafanadocsplugin-app',
   'grafana-pathfinder-app',
+  'grafana-grotfood-app',
 ];
 
 export type ExtensionSidebarContextType = {
@@ -90,19 +91,28 @@ export const ExtensionSidebarContextProvider = ({ children }: ExtensionSidebarCo
   // that means, a plugin would need to register both, a link and a component to
   // `grafana/extension-sidebar/v0-alpha` and the link's `configure` method would control
   // whether the component is rendered or not
-  const { links, isLoading } = usePluginLinks({
+  const { links, isLoading: isPluginLinksLoading } = usePluginLinks({
     extensionPointId: PluginExtensionPoints.ExtensionSidebar,
     context: {
       path: currentPath,
     },
   });
 
+  const { loading: isExtensionPointPluginMetaLoading, value: pluginMap } = useAsync(() =>
+    getExtensionPointPluginMeta(PluginExtensionPoints.ExtensionSidebar)
+  );
+
+  const isLoading = useMemo(
+    () => isPluginLinksLoading || isExtensionPointPluginMetaLoading,
+    [isPluginLinksLoading, isExtensionPointPluginMetaLoading]
+  );
+
   // get all components for this extension point, but only for the permitted plugins
   // if the extension sidebar is not enabled, we will return an empty map
   const availableComponents = useMemo(
     () =>
       new Map(
-        Array.from(getExtensionPointPluginMeta(PluginExtensionPoints.ExtensionSidebar).entries()).filter(
+        Array.from(pluginMap?.entries() || []).filter(
           ([pluginId, pluginMeta]) =>
             PERMITTED_EXTENSION_SIDEBAR_PLUGINS.includes(pluginId) &&
             links.some(
@@ -112,7 +122,7 @@ export const ExtensionSidebarContextProvider = ({ children }: ExtensionSidebarCo
             )
         )
       ),
-    [links]
+    [links, pluginMap]
   );
 
   // check if the stored docked component is still available
