@@ -4,7 +4,6 @@ import * as React from 'react';
 import { GrafanaTheme2 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
 import { t } from '@grafana/i18n';
-import { config } from '@grafana/runtime';
 import { Icon, IconButton, Link, useTheme2 } from '@grafana/ui';
 import { contextSrv } from 'app/core/services/context_srv';
 
@@ -36,12 +35,7 @@ export function MegaMenuItemText({ children, isActive, onClick, target, url, onP
   );
 
   return (
-    <div
-      className={cx(styles.wrapper, {
-        [styles.wrapperActive]: isActive,
-        [styles.wrapperBookmark]: config.featureToggles.pinNavItems,
-      })}
-    >
+    <div className={cx(styles.wrapper, isActive && styles.wrapperActive)}>
       <LinkComponent
         data-testid={selectors.components.NavMenu.item}
         className={styles.container}
@@ -52,7 +46,7 @@ export function MegaMenuItemText({ children, isActive, onClick, target, url, onP
       >
         {linkContent}
       </LinkComponent>
-      {config.featureToggles.pinNavItems && contextSrv.isSignedIn && url && url !== '/bookmarks' && (
+      {contextSrv.isSignedIn && url && url !== '/bookmarks' && (
         <IconButton
           name="bookmark"
           className={'pin-icon'}
@@ -77,8 +71,6 @@ const getStyles = (theme: GrafanaTheme2, isActive: Props['isActive']) => ({
     justifyContent: 'space-between',
     width: '100%',
     height: '100%',
-  }),
-  wrapperBookmark: css({
     '.pin-icon': {
       visibility: 'hidden',
     },
@@ -96,6 +88,7 @@ const getStyles = (theme: GrafanaTheme2, isActive: Props['isActive']) => ({
     borderTopRightRadius: theme.shape.radius.default,
     borderBottomRightRadius: theme.shape.radius.default,
     position: 'relative',
+    color: theme.colors.text.primary,
 
     '&::before': {
       backgroundImage: theme.colors.gradients.brandVertical,
@@ -105,7 +98,8 @@ const getStyles = (theme: GrafanaTheme2, isActive: Props['isActive']) => ({
       height: '100%',
       position: 'absolute',
       transform: 'translateX(-50%)',
-      width: theme.spacing(0.5),
+      left: 0,
+      width: theme.spacing(0.25),
     },
   }),
   container: css({
