@@ -2,7 +2,7 @@ import { css } from '@emotion/css';
 import * as React from 'react';
 
 import { GrafanaTheme2, NavModelItem } from '@grafana/data';
-import { usePluginComponents } from '@grafana/runtime';
+import { usePluginComponents, usePluginLinks } from '@grafana/runtime';
 import { useStyles2 } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { useNavModel } from 'app/core/hooks/useNavModel';
@@ -15,6 +15,7 @@ interface Props {
 }
 
 const EXTENSION_ID = (nodeId: string) => `grafana/dynamic/nav-landing-page/nav-id-${nodeId}/v1`;
+const CARDS_EXTENSION_ID = (nodeId: string) => `grafana/dynamic/nav-landing-page/nav-id-${nodeId}/cards/v1`;
 
 export function NavLandingPage({ navId, header }: Props) {
   const { node } = useNavModel(navId);
@@ -27,7 +28,23 @@ export function NavLandingPage({ navId, header }: Props) {
     extensionPointId: EXTENSION_ID(node.id ?? ''),
   });
 
-  if (isLoading) {
+  const { links: additionalCards, isLoading: isLoadingCards } = usePluginLinks({
+    extensionPointId: CARDS_EXTENSION_ID(node.id ?? ''),
+    context: { node },
+  });
+
+  // Warn if both extension points are being used (they are mutually exclusive)
+  React.useEffect(() => {
+    if (components && components.length > 0 && additionalCards && additionalCards.length > 0) {
+      console.warn(
+        `[NavLandingPage] Both NavLandingPage and NavLandingPageCards extensions are registered for "${node.id}". ` +
+          `The NavLandingPage extension will take precedence and NavLandingPageCards will be ignored. ` +
+          `Please use only one extension point.`
+      );
+    }
+  }, [components, additionalCards, node.id]);
+
+  if (isLoading || isLoadingCards) {
     return null;
   }
 
@@ -49,6 +66,16 @@ export function NavLandingPage({ navId, header }: Props) {
                     url={child.url ?? ''}
                   />
                 ))}
+                {additionalCards?.map((link) => (
+                  <NavLandingPageCard
+                    key={link.id}
+                    description={link.description}
+                    text={link.title}
+                    url={link.path ?? ''}
+                    category={link.category}
+                    onClick={link.onClick}
+                  />
+                ))}
               </section>
             )}
           </div>
