@@ -1,31 +1,64 @@
 import { fireEvent, render, screen } from 'test/test-utils';
 
-import { setBackendSrv } from '@grafana/runtime';
+import { config, setBackendSrv } from '@grafana/runtime';
 import { setupMockServer } from '@grafana/test-utils/server';
 import { getFolderFixtures } from '@grafana/test-utils/unstable';
 import { backendSrv } from 'app/core/services/backend_srv';
 
 import { NestedFolderPicker } from './NestedFolderPicker';
+import { useGetTeamFolders } from './useTeamOwnedFolder';
 
 const [_, { folderA, folderB, folderC, folderA_folderA, folderA_folderB, folderA_folderC }] = getFolderFixtures();
 
 setupMockServer();
 setBackendSrv(backendSrv);
 
+jest.mock('./useTeamOwnedFolder', () => {
+  const actual = jest.requireActual('./useTeamOwnedFolder');
+  return {
+    ...actual,
+    useGetTeamFolders: jest.fn(),
+  };
+});
+
 describe('NestedFolderPicker', () => {
   const mockOnChange = jest.fn();
   const originalScrollIntoView = window.HTMLElement.prototype.scrollIntoView;
+  let featureTogglesBackup: typeof config.featureToggles;
+  const useGetTeamFoldersMock = useGetTeamFolders as jest.Mock;
 
   beforeAll(() => {
     window.HTMLElement.prototype.scrollIntoView = function () {};
+    featureTogglesBackup = { ...config.featureToggles };
+  });
+
+  beforeEach(() => {
+    useGetTeamFoldersMock.mockImplementation((options?: { skip: boolean }) => {
+      if (options?.skip) {
+        return { foldersByTeam: [], isLoading: false, error: undefined };
+      }
+
+      return {
+        foldersByTeam: [
+          {
+            team: { name: 'Team A', avatarUrl: 'https://example.com/avatar.png' },
+            folders: [{ name: 'team-folder-1', title: 'Team Folder One' }],
+          },
+        ],
+        isLoading: false,
+        error: undefined,
+      };
+    });
   });
 
   afterAll(() => {
     window.HTMLElement.prototype.scrollIntoView = originalScrollIntoView;
+    config.featureToggles = featureTogglesBackup;
   });
 
   afterEach(() => {
     jest.resetAllMocks();
+    config.featureToggles = { ...featureTogglesBackup };
   });
 
   it('renders a button with the correct label when no folder is selected', async () => {
@@ -111,7 +144,7 @@ describe('NestedFolderPicker', () => {
     expect(screen.queryByLabelText('Dashboards')).not.toBeInTheDocument();
   });
 
-  it('hides folders specififed by UID', async () => {
+  it('hides folders specified by UID', async () => {
     const { user } = render(<NestedFolderPicker excludeUIDs={[folderC.item.uid]} onChange={mockOnChange} />);
 
     // Open the picker and wait for children to load
@@ -201,4 +234,50 @@ describe('NestedFolderPicker', () => {
     await user.keyboard('{ArrowDown}{Enter}');
     expect(mockOnChange).toHaveBeenCalledWith(folderA_folderC.item.uid, folderA_folderC.item.title);
   });
+
+  it('shows team folders when feature toggle is enabled', async () => {
+    config.featureToggles.teamFolders = true;
+    const { user } = render(<NestedFolderPicker onChange={mockOnChange} />);
+    await user.click(await screen.findByRole('button', { name: 'Select folder' }));
+
+    expect(await screen.findByLabelText('Team folders')).toBeInTheDocument();
+    expect(await screen.findByLabelText('Team Folder One')).toBeInTheDocument();
+  });
+
+  it('shows team folders at top level when root folder is hidden', async () => {
+    config.featureToggles.teamFolders = true;
+    const { user } = render(<NestedFolderPicker showRootFolder={false} onChange={mockOnChange} />);
+    await user.click(await screen.findByRole('button', { name: 'Select folder' }));
+
+    const teamFolders = await screen.findByLabelText('Team folders');
+    const topLevelFolder = await screen.findByLabelText(folderA.item.title);
+
+    expect(screen.queryByLabelText('Dashboards')).not.toBeInTheDocument();
+    expect(teamFolders).toBeInTheDocument();
+    expect(await screen.findByLabelText('Team Folder One')).toBeInTheDocument();
+    expect(teamFolders.getAttribute('aria-level')).toBe(topLevelFolder.getAttribute('aria-level'));
+  });
+
+  it('does not render team folders when feature toggle is disabled', async () => {
+    config.featureToggles.teamFolders = false;
+    const { user } = render(<NestedFolderPicker onChange={mockOnChange} />);
+    await user.click(await screen.findByRole('button', { name: 'Select folder' }));
+
+    expect(screen.queryByLabelText('Team folders')).not.toBeInTheDocument();
+    expect(screen.queryByLabelText('Team Folder One')).not.toBeInTheDocument();
+  });
+
+  it('does auto-select a team folder when root is selected', () => {
+    config.featureToggles.teamFolders = true;
+    render(<NestedFolderPicker value="" onChange={mockOnChange} />);
+
+    expect(mockOnChange).toHaveBeenCalled();
+  });
+
+  it('does not auto-select a team folder when no value', () => {
+    config.featureToggles.teamFolders = true;
+    render(<NestedFolderPicker onChange={mockOnChange} />);
+
+    expect(mockOnChange).not.toHaveBeenCalled();
+  });
 });
