@@ -8,7 +8,7 @@ import AutoSizer from 'react-virtualized-auto-sizer';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { Trans, t } from '@grafana/i18n';
-import { isFetchError, locationService } from '@grafana/runtime';
+import { config, isFetchError, locationService } from '@grafana/runtime';
 import {
   Alert,
   Box,
@@ -26,14 +26,20 @@ import {
   useStyles2,
 } from '@grafana/ui';
 import { useAppNotification } from 'app/core/copy/appNotification';
+import { contextSrv } from 'app/core/services/context_srv';
 import { ActiveTab as ContactPointsActiveTabs } from 'app/features/alerting/unified/components/contact-points/ContactPoints';
 import { TestTemplateAlert } from 'app/plugins/datasource/alertmanager/types';
+import { AccessControlAction } from 'app/types/accessControl';
 
 import { AITemplateButtonComponent } from '../../enterprise-components/AI/AIGenTemplateButton/addAITemplateButton';
+import { KnownProvenance } from '../../types/knownProvenance';
 import { GRAFANA_RULES_SOURCE_NAME } from '../../utils/datasource';
+import { DOCS_URL_TEMPLATE_EXAMPLES, DOCS_URL_TEMPLATE_NOTIFICATIONS } from '../../utils/docs';
+import { isProvisionedResource } from '../../utils/k8s/utils';
 import { makeAMLink, stringifyErrorLike } from '../../utils/misc';
+import { ALERTING_PATHS } from '../../utils/navigation';
 import { EditorColumnHeader } from '../EditorColumnHeader';
-import { ProvisionedResource, ProvisioningAlert } from '../Provisioning';
+import { ImportedResourceAlert, ProvisionedResource, ProvisioningAlert } from '../Provisioning';
 import { Spacer } from '../Spacer';
 import {
   NotificationTemplate,
@@ -100,6 +106,16 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
   const formRef = useRef<HTMLFormElement>(null);
   const isGrafanaAlertManager = alertmanager === GRAFANA_RULES_SOURCE_NAME;
 
+  // Check if user has permission to test templates
+  const canTestTemplates =
+    contextSrv.hasPermission(AccessControlAction.AlertingNotificationsTemplatesTest) ||
+    contextSrv.hasPermission(AccessControlAction.AlertingNotificationsWrite);
+
+  // Only show preview and payload panels if both conditions are met:
+  // 1. It's a Grafana Alertmanager
+  // 2. User has the test permission
+  const showPreviewAndPayload = isGrafanaAlertManager && canTestTemplates;
+
   const error = updateTemplateError ?? createTemplateError;
 
   const [cheatsheetOpened, toggleCheatsheetOpened] = useToggle(false);
@@ -110,7 +126,9 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
   // AI feedback state
   const [aiGeneratedTemplate, setAiGeneratedTemplate] = useState(false);
 
-  const { isProvisioned } = useNotificationTemplateMetadata(originalTemplate);
+  const { provenance } = useNotificationTemplateMetadata(originalTemplate);
+  const isProvisioned = isProvisionedResource(provenance);
+  const isImported = provenance === KnownProvenance.ConvertedPrometheus;
   const originalTemplatePrefill: TemplateFormValues | undefined = originalTemplate
     ? { title: originalTemplate.title, content: originalTemplate.content }
     : undefined;
@@ -118,16 +136,16 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
   // splitter for template and payload editor
   const columnSplitter = useSplitter({
     direction: 'column',
-    // if Grafana Alertmanager, split 50/50, otherwise 100/0 because there is no payload editor
-    initialSize: isGrafanaAlertManager ? 0.5 : 1,
+    // if showing preview/payload panels, split 50/50, otherwise 100/0 because there is no payload editor
+    initialSize: showPreviewAndPayload ? 0.5 : 1,
     dragPosition: 'middle',
   });
 
   // splitter for template editor and preview
   const rowSplitter = useSplitter({
     direction: 'row',
-    // if Grafana Alertmanager, split 60/40, otherwise 100/0 because there is no preview
-    initialSize: isGrafanaAlertManager ? 0.6 : 1,
+    // if showing preview/payload panels, split 60/40, otherwise 100/0 because there is no preview
+    initialSize: showPreviewAndPayload ? 0.6 : 1,
     dragPosition: 'middle',
   });
 
@@ -145,9 +163,13 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
   } = formApi;
 
   const submit = async (values: TemplateFormValues) => {
-    const returnLink = makeAMLink('/alerting/notifications', alertmanager, {
-      tab: ContactPointsActiveTabs.NotificationTemplates,
-    });
+    // V2 nav has dedicated templates page, legacy nav uses tab parameter
+    const useV2Nav = config.featureToggles.alertingNavigationV2;
+    const returnLink = useV2Nav
+      ? makeAMLink(ALERTING_PATHS.TEMPLATES, alertmanager)
+      : makeAMLink(ALERTING_PATHS.NOTIFICATIONS, alertmanager, {
+          tab: ContactPointsActiveTabs.NotificationTemplates,
+        });
 
     try {
       if (!originalTemplate) {
@@ -192,7 +214,12 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
             </Alert>
           )}
           {/* warning about provisioned template */}
-          {isProvisioned && (
+          {isProvisioned && isImported && (
+            <Box grow={0}>
+              <ImportedResourceAlert resource={ProvisionedResource.Template} />
+            </Box>
+          )}
+          {isProvisioned && !isImported && (
             <Box grow={0}>
               <ProvisioningAlert resource={ProvisionedResource.Template} />
             </Box>
@@ -272,7 +299,7 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
                                             'alerting.template-form.label-examples-documentation',
                                             'Examples documentation'
                                           )}
-                                          url="https://grafana.com/docs/grafana/latest/alerting/configure-notifications/template-notifications/examples/"
+                                          url={DOCS_URL_TEMPLATE_EXAMPLES}
                                           target="_blank"
                                           icon="external-link-alt"
                                         />
@@ -319,8 +346,8 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
                         </Box>
                       </div>
                     </div>
-                    {/* payload editor – only available for Grafana Alertmanager */}
-                    {isGrafanaAlertManager && (
+                    {/* payload editor – only shown if user has test permission */}
+                    {showPreviewAndPayload && (
                       <>
                         <div {...columnSplitter.splitterProps} />
                         <div {...columnSplitter.secondaryProps}>
@@ -345,8 +372,8 @@ export const TemplateForm = ({ originalTemplate, prefill, alertmanager }: Props)
                     )}
                   </div>
                 </div>
-                {/* preview column – full height and half-width */}
-                {isGrafanaAlertManager && (
+                {/* preview column – only shown if user has test permission */}
+                {showPreviewAndPayload && (
                   <div {...rowSplitter.secondaryProps}>
                     <div {...rowSplitter.splitterProps} />
                     <TemplatePreview
@@ -398,7 +425,7 @@ For detailed information about notification templates, refer to our documentatio
           <div style={{ whiteSpace: 'pre' }}>{intro}</div>
           <div>
             <LinkButton
-              href="https://grafana.com/docs/grafana/latest/alerting/manage-notifications/template-notifications/"
+              href={DOCS_URL_TEMPLATE_NOTIFICATIONS}
               target="_blank"
               icon="external-link-alt"
               variant="secondary"
