@@ -1,4 +1,5 @@
 import * as React from 'react';
+import type { JSX } from 'react';
 import { DeepMap, FieldError, FieldErrors, useFormContext } from 'react-hook-form';
 
 import { Field, SecretInput } from '@grafana/ui';
@@ -29,8 +30,8 @@ export interface Props<R extends ChannelValues> {
    * This is used to access the settings and secure fields for the integration in a type-safe way.
    */
   integrationPrefix: `items.${number}`;
+  canEditProtectedFields: boolean;
   readOnly?: boolean;
-
   customValidators?: Record<string, React.ComponentProps<typeof OptionField>['customValidator']>;
 }
 
@@ -43,6 +44,7 @@ export function ChannelOptions<R extends ChannelValues>({
   integrationPrefix,
   readOnly = false,
   customValidators = {},
+  canEditProtectedFields,
 }: Props<R>): JSX.Element {
   const { watch } = useFormContext<ReceiverFormValues<CloudChannelValues | GrafanaChannelValues>>();
 
@@ -53,7 +55,7 @@ export function ChannelOptions<R extends ChannelValues>({
 
   const getOptionMeta = (option: NotificationChannelOption): OptionMeta => ({
     required: determineRequired(option, settings, secureFields),
-    readOnly: determineReadOnly(option, settings, secureFields),
+    readOnly: determineReadOnly(option, settings, secureFields, canEditProtectedFields),
   });
 
   return (
@@ -77,6 +79,7 @@ export function ChannelOptions<R extends ChannelValues>({
               label={option.label}
               description={option.description}
               htmlFor={`${settingsPath}${option.propertyName}`}
+              noMargin
             >
               <SecretInput
                 id={`${settingsPath}${option.propertyName}`}
@@ -87,9 +90,12 @@ export function ChannelOptions<R extends ChannelValues>({
           );
         }
 
-        const error: FieldError | DeepMap<any, FieldError> | undefined = (
-          (option.secure ? errors?.secureFields : errors?.settings) as DeepMap<any, FieldError> | undefined
-        )?.[option.secureFieldKey ?? option.propertyName];
+        const errorSource = option.secure ? errors?.secureFields : errors?.settings;
+        const propertyKey = option.secureFieldKey ?? option.propertyName;
+        const error = // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
+          (errorSource as Record<string, FieldError | DeepMap<Record<string, unknown>, FieldError>> | undefined)?.[
+            propertyKey
+          ];
 
         const defaultValue = defaultValues?.settings?.[option.propertyName];
 
@@ -139,8 +145,14 @@ const determineRequired = (
 const determineReadOnly = (
   option: NotificationChannelOption,
   settings: Record<string, unknown>,
-  secureFields: NotificationChannelSecureFields
+  secureFields: NotificationChannelSecureFields,
+  canEditProtectedFields: boolean
 ) => {
+  if (option.protected && !canEditProtectedFields) {
+    return true;
+  }
+
+  // Handle fields with dependencies (e.g., field B depends on field A being set)
   if (!option.dependsOn) {
     return false;
   }
