@@ -11,6 +11,7 @@ import { AlertmanagerChoice } from 'app/plugins/datasource/alertmanager/types';
 import { alertmanagerApi } from '../../api/alertmanagerApi';
 import { KBObjectArray, RuleFormType, RuleFormValues } from '../../types/rule-form';
 import { GRAFANA_RULES_SOURCE_NAME } from '../../utils/datasource';
+import { DOCS_URL_NOTIFICATIONS, DOCS_URL_NOTIFICATION_POLICIES } from '../../utils/docs';
 import { isGrafanaManagedRuleByType, isGrafanaRecordingRuleByType, isRecordingRuleByType } from '../../utils/rules';
 
 import { NeedHelpInfo } from './NeedHelpInfo';
@@ -19,6 +20,7 @@ import { SimplifiedRouting } from './alert-rule-form/simplifiedRouting/Simplifie
 import { LabelsEditorModal } from './labels/LabelsEditorModal';
 import { LabelsFieldInForm } from './labels/LabelsFieldInForm';
 import { NotificationPreview } from './notificaton-preview/NotificationPreview';
+import { PolicyTreeSelector } from './notificaton-preview/PolicyTreeSelector';
 
 type NotificationsStepProps = {
   alertUid?: string;
@@ -237,15 +239,21 @@ function AutomaticRooting({ alertUid }: AutomaticRootingProps) {
     'name',
     'manualRouting',
   ]);
+
+  const multiplePoliciesEnabled = config.featureToggles.alertingMultiplePolicies ?? false;
+
   return (
-    <NotificationPreview
-      alertQueries={queries}
-      customLabels={labels}
-      condition={condition}
-      folder={folder}
-      alertName={alertName}
-      alertUid={alertUid}
-    />
+    <Stack direction="column" gap={2}>
+      {multiplePoliciesEnabled && <PolicyTreeSelector />}
+      <NotificationPreview
+        alertQueries={queries}
+        customLabels={labels}
+        condition={condition}
+        folder={folder}
+        alertName={alertName}
+        alertUid={alertUid}
+      />
+    </Stack>
   );
 }
 
@@ -266,10 +274,7 @@ function NeedHelpInfoForNotificationPolicy() {
               Custom labels change the way your notifications are routed. First, add labels to your alert rule and then
               connect them to your notification policy by adding label matchers.
             </Trans>
-            <TextLink
-              href={`https://grafana.com/docs/grafana/latest/alerting/fundamentals/notifications/notification-policies/`}
-              external
-            >
+            <TextLink href={DOCS_URL_NOTIFICATION_POLICIES} external>
               <Trans i18nKey="alerting.need-help-info-for-notification-policy.read-more">
                 Read about notification policies.
               </Trans>
@@ -302,7 +307,7 @@ function NeedHelpInfoForContactpoint() {
           </Trans>
         </>
       }
-      externalLink="https://grafana.com/docs/grafana/latest/alerting/fundamentals/notifications/"
+      externalLink={DOCS_URL_NOTIFICATIONS}
       linkText="Read more about notifications"
       title={t(
         'alerting.need-help-info-for-contactpoint.title-notify-by-selecting-a-contact-point',
