@@ -4,7 +4,7 @@ import { GrafanaPromRuleDTO, PromRuleType } from 'app/types/unified-alerting-dto
 import { GRAFANA_RULES_SOURCE_NAME, GrafanaRulesSource } from '../utils/datasource';
 import { groups } from '../utils/navigation';
 import { totalFromStats } from '../utils/ruleStats';
-import { prometheusRuleType } from '../utils/rules';
+import { getRulePluginOrigin, prometheusRuleType } from '../utils/rules';
 import { createRelativeUrl } from '../utils/url';
 
 import {
@@ -53,6 +53,7 @@ export function GrafanaRuleListItem({
     application: 'grafana' as const,
     actions: <RuleActionsButtons promRule={rule} groupIdentifier={groupIdentifier} compact />,
     querySourceUIDs: rule?.queriedDatasourceUIDs,
+    origin: getRulePluginOrigin(rule),
   };
 
   if (prometheusRuleType.grafana.alertingRule(rule)) {
