@@ -1,7 +1,10 @@
+import { t } from '@grafana/i18n';
 import { Icon, Stack, TextLink, Tooltip } from '@grafana/ui';
 import { RulesSourceIdentifier } from 'app/types/unified-alerting';
 import { RulesSourceApplication } from 'app/types/unified-alerting-dto';
 
+import { isUngroupedRuleGroup } from '../../utils/rules';
+
 import { DataSourceIcon } from './DataSourceIcon';
 
 interface RuleLocationProps {
@@ -15,6 +18,7 @@ interface RuleLocationProps {
 export function RuleLocation({ namespace, group, groupUrl, rulesSource, application }: RuleLocationProps) {
   const isGrafanaApp = application === 'grafana';
   const isDataSourceApp = !!rulesSource && !!application && !isGrafanaApp;
+  const groupText = isUngroupedRuleGroup(group) ? t('alerting.rules-group.ungrouped', 'Ungrouped') : group;
 
   return (
     <Stack direction="row" alignItems="center" gap={0.5}>
@@ -32,10 +36,10 @@ export function RuleLocation({ namespace, group, groupUrl, rulesSource, applicat
         <Icon size="sm" name="angle-right" />
         {groupUrl ? (
           <TextLink href={groupUrl} color="secondary" variant="bodySmall" inline={false}>
-            {group}
+            {groupText}
           </TextLink>
         ) : (
-          group
+          groupText
         )}
       </Stack>
     </Stack>
