@@ -1,28 +1,33 @@
 import { createApi } from '@reduxjs/toolkit/query/react';
 
-import { AppEvents, isTruthy, locationUtil } from '@grafana/data';
+import { handleRequestError } from '@grafana/api-clients';
+import { createBaseQuery } from '@grafana/api-clients/rtkq';
+import { generatedAPI as legacyUserAPI } from '@grafana/api-clients/rtkq/legacy/user';
+import { AppEvents, locationUtil } from '@grafana/data';
 import { t } from '@grafana/i18n';
 import { config, getBackendSrv, isFetchError, locationService } from '@grafana/runtime';
 import { Dashboard } from '@grafana/schema';
-import { Spec as DashboardV2Spec } from '@grafana/schema/dist/esm/schema/dashboard/v2';
+import { Spec as DashboardV2Spec } from '@grafana/schema/apis/dashboard.grafana.app/v2';
 import { isProvisionedFolderCheck } from 'app/api/clients/folder/v1beta1/utils';
-import { createBaseQuery, handleRequestError } from 'app/api/createBaseQuery';
-import appEvents from 'app/core/app_events';
-import { contextSrv } from 'app/core/core';
+import { appEvents } from 'app/core/app_events';
+import { buildNotificationButton } from 'app/core/components/AppNotifications/NotificationButton';
+import { createSuccessNotification } from 'app/core/copy/appNotification';
+import { notifyApp } from 'app/core/reducers/appNotification';
+import { setStarred } from 'app/core/reducers/navBarTree';
+import { contextSrv } from 'app/core/services/context_srv';
 import { AnnoKeyFolder, Resource, ResourceList } from 'app/features/apiserver/types';
 import { getDashboardAPI } from 'app/features/dashboard/api/dashboard_api';
 import { isDashboardV2Resource, isV1DashboardCommand, isV2DashboardCommand } from 'app/features/dashboard/api/utils';
 import { SaveDashboardCommand } from 'app/features/dashboard/components/SaveDashboard/types';
 import { dashboardWatcher } from 'app/features/live/dashboard/dashboardWatcher';
 import { dispatch } from 'app/store/store';
-import { PermissionLevelString } from 'app/types/acl';
-import { SaveDashboardResponseDTO, ImportDashboardResponseDTO } from 'app/types/dashboard';
-import { FolderListItemDTO, FolderDTO, DescendantCount, DescendantCountDTO } from 'app/types/folders';
+import { PermissionLevel } from 'app/types/acl';
+import { ImportDashboardResponseDTO, SaveDashboardResponseDTO } from 'app/types/dashboard';
+import { DescendantCount, DescendantCountDTO, FolderDTO, FolderListItemDTO } from 'app/types/folders';
 
 import { getDashboardScenePageStateManager } from '../../dashboard-scene/pages/DashboardScenePageStateManager';
 import { deletedDashboardsCache } from '../../search/service/deletedDashboardsCache';
 import { refetchChildren, refreshParents } from '../state/actions';
-import { DashboardTreeSelection } from '../types';
 
 import { isProvisionedDashboard } from './isProvisioned';
 import { PAGE_SIZE } from './services';
@@ -72,7 +77,7 @@ export interface ListFolderQueryArgs {
   page: number;
   parentUid: string | undefined;
   limit: number;
-  permission?: PermissionLevelString;
+  permission?: PermissionLevel;
 }
 
 export const browseDashboardsAPI = createApi({
@@ -92,9 +97,17 @@ export const browseDashboardsAPI = createApi({
     }),
 
     // get folder info (e.g. title, parents) but *not* children
-    getFolder: builder.query<FolderDTO, string>({
-      providesTags: (_result, _error, folderUID) => [{ type: 'getFolder', id: folderUID }],
-      query: (folderUID) => ({ url: `/folders/${folderUID}`, params: { accesscontrol: true } }),
+    getFolder: builder.query<FolderDTO, { folderUID: string; accesscontrol: boolean; isLegacyCall: boolean }>({
+      providesTags: (_result, _error, { folderUID }) => [{ type: 'getFolder', id: folderUID }],
+      query: ({ folderUID, accesscontrol, isLegacyCall }) => ({
+        url: `/folders/${folderUID}`,
+        params: {
+          accesscontrol,
+          // Add additional query param so we can tell when
+          // this was called for app platform compatibility purposes vs. actually needing to use the legacy API
+          isLegacyCall,
+        },
+      }),
     }),
 
     // create a new folder
@@ -169,6 +182,7 @@ export const browseDashboardsAPI = createApi({
 
     // delete an *individual* folder. used in the folder actions menu.
     deleteFolder: builder.mutation<void, FolderDTO>({
+      invalidatesTags: ['getFolder'],
       query: ({ uid }) => ({
         url: `/folders/${uid}`,
         method: 'DELETE',
@@ -191,33 +205,34 @@ export const browseDashboardsAPI = createApi({
     }),
 
     // gets the descendant counts for a folder. used in the move/delete modals.
-    getAffectedItems: builder.query<DescendantCount, DashboardTreeSelection>({
+    getAffectedItems: builder.query<DescendantCount, { folderUIDs: string[]; dashboardUIDs: string[] }>({
       // don't cache this data for now, since library panel/alert rule creation isn't done through rtk query
       keepUnusedDataFor: 0,
-      queryFn: async (selectedItems) => {
-        const folderUIDs = Object.keys(selectedItems.folder).filter((uid) => selectedItems.folder[uid]);
+      queryFn: async ({ folderUIDs, dashboardUIDs }) => {
+        try {
+          const promises = folderUIDs.map((folderUID) => {
+            return getBackendSrv().get<DescendantCountDTO>(`/api/folders/${folderUID}/counts`);
+          });
+          const results = await Promise.all(promises);
 
-        const promises = folderUIDs.map((folderUID) => {
-          return getBackendSrv().get<DescendantCountDTO>(`/api/folders/${folderUID}/counts`);
-        });
+          const totalCounts: DescendantCount = {
+            folders: folderUIDs.length,
+            dashboards: dashboardUIDs.length,
+            library_elements: 0,
+            alertrules: 0,
+          };
 
-        const results = await Promise.all(promises);
+          for (const folderCounts of results) {
+            totalCounts.folders += folderCounts.folder;
+            totalCounts.dashboards += folderCounts.dashboard;
+            totalCounts.alertrules += folderCounts.alertrule;
+            totalCounts.library_elements += folderCounts.librarypanel;
+          }
 
-        const totalCounts = {
-          folder: Object.values(selectedItems.folder).filter(isTruthy).length,
-          dashboard: Object.values(selectedItems.dashboard).filter(isTruthy).length,
-          libraryPanel: 0,
-          alertRule: 0,
-        };
-
-        for (const folderCounts of results) {
-          totalCounts.folder += folderCounts.folder;
-          totalCounts.dashboard += folderCounts.dashboard;
-          totalCounts.alertRule += folderCounts.alertrule;
-          totalCounts.libraryPanel += folderCounts.librarypanel;
+          return { data: totalCounts };
+        } catch (error) {
+          return { error };
         }
-
-        return { data: totalCounts };
       },
     }),
 
@@ -339,45 +354,83 @@ export const browseDashboardsAPI = createApi({
     // delete *multiple* dashboards. used in the delete modal.
     deleteDashboards: builder.mutation<void, DeleteDashboardsArgs>({
       invalidatesTags: ['getFolder'],
-      queryFn: async ({ dashboardUIDs }, _api, _extraOptions, baseQuery) => {
+      queryFn: async ({ dashboardUIDs }) => {
         const pageStateManager = getDashboardScenePageStateManager();
+        const restoreDashboardsEnabled = config.featureToggles.restoreDashboards;
+        let deletedCount = 0;
+        const deletedDashboardUIDs: string[] = [];
         // Delete all the dashboards sequentially
         // TODO error handling here
-        for (const dashboardUID of dashboardUIDs) {
-          if (config.featureToggles.provisioning) {
-            const dto = await getDashboardAPI().getDashboardDTO(dashboardUID);
-            if (isProvisionedDashboard(dto)) {
-              appEvents.publish({
-                type: AppEvents.alertWarning.name,
-                payload: [
-                  'Cannot delete provisioned dashboard. To remove it, delete it from the repository and synchronise to apply the changes.',
-                ],
-              });
+        try {
+          for (const dashboardUID of dashboardUIDs) {
+            // It's not possible to select a mix of provisioned and non-provisioned dashboards
+            // from the UI, so this is mostly a guard in case that somehow happens
+            if (config.featureToggles.provisioning) {
+              const dto = await getDashboardAPI().getDashboardDTO(dashboardUID);
+              if (isProvisionedDashboard(dto)) {
+                appEvents.publish({
+                  type: AppEvents.alertWarning.name,
+                  payload: [
+                    'Cannot delete provisioned dashboard. To remove it, delete it from the repository and synchronise to apply the changes.',
+                  ],
+                });
+                continue;
+              }
+            }
+            await getDashboardAPI().deleteDashboard(dashboardUID, !restoreDashboardsEnabled);
 
-              continue;
+            deletedCount++;
+            deletedDashboardUIDs.push(dashboardUID);
+          }
+        } finally {
+          if (deletedCount > 0) {
+            pageStateManager.clearDashboardCache();
+            deletedDashboardsCache.clear();
+            for (const uid of deletedDashboardUIDs) {
+              pageStateManager.removeSceneCache(uid);
+            }
+
+            // Show success notification after all deletions
+            if (restoreDashboardsEnabled) {
+              // Show notification with button to Recently Deleted
+              const title =
+                deletedCount === 1
+                  ? t('browse-dashboards.delete.success-single', 'Dashboard deleted')
+                  : t('browse-dashboards.delete.success-multiple', 'Dashboards deleted');
+              const buttonText = t('browse-dashboards.delete.view-recently-deleted', 'View deleted dashboards');
+              const component = buildNotificationButton({
+                title,
+                buttonLabel: buttonText,
+                href: config.appSubUrl + '/dashboard/recently-deleted',
+              });
+              dispatch(notifyApp(createSuccessNotification('', '', undefined, component)));
+            } else if (config.featureToggles.kubernetesDashboards) {
+              // Legacy notification for kubernetes dashboards
+              appEvents.publish({
+                type: AppEvents.alertSuccess.name,
+                payload: ['Dashboard deleted'],
+              });
             }
           }
-
-          await getDashboardAPI().deleteDashboard(dashboardUID, true);
-
-          pageStateManager.clearDashboardCache();
-          pageStateManager.removeSceneCache(dashboardUID);
-          deletedDashboardsCache.clear();
-
-          // handling success alerts for these feature toggles
-          // for legacy response, the success alert will be triggered by showSuccessAlert function in public/app/core/services/backend_srv.ts
-          if (config.featureToggles.kubernetesDashboards) {
-            appEvents.publish({
-              type: AppEvents.alertSuccess.name,
-              payload: ['Dashboard deleted'],
-            });
-          }
         }
+
         return { data: undefined };
       },
-      onQueryStarted: ({ dashboardUIDs }, { queryFulfilled, dispatch }) => {
+      onQueryStarted: ({ dashboardUIDs }, { queryFulfilled, getState }) => {
         queryFulfilled.then(() => {
           dispatch(refreshParents(dashboardUIDs));
+          dispatch(legacyUserAPI.util.invalidateTags(['dashboardStars']));
+          for (const uid of dashboardUIDs) {
+            dispatch(
+              setStarred({
+                id: uid,
+                // We don't need to send the title or url as we're removing the starred items here
+                title: '',
+                url: '',
+                isStarred: false,
+              })
+            );
+          }
         });
       },
     }),
@@ -392,7 +445,7 @@ export const browseDashboardsAPI = createApi({
           }
 
           if (isV1DashboardCommand(cmd)) {
-            const rsp = await getDashboardAPI().saveDashboard(cmd);
+            const rsp = await getDashboardAPI('v1').saveDashboard(cmd);
             return { data: rsp };
           }
           throw new Error('Invalid dashboard version');
@@ -489,31 +542,24 @@ export const browseDashboardsAPI = createApi({
     }),
 
     // restore a dashboard that got deleted
-    restoreDashboard: builder.mutation<void, RestoreDashboardArgs>({
+    restoreDashboard: builder.mutation<{ name: string }, RestoreDashboardArgs>({
       invalidatesTags: ['getFolder'],
       queryFn: async ({ dashboard }) => {
         try {
           const api = getDashboardAPI();
           const response = await api.restoreDashboard(dashboard);
-          const name = response.spec.title;
+          const name = response.spec.title || '';
           const parentFolder = response.metadata?.annotations?.[AnnoKeyFolder];
 
-          if (name) {
-            appEvents.publish({
-              type: AppEvents.alertSuccess.name,
-              payload: [t('browse-dashboards.restore.success', 'Dashboard {{name}} restored', { name })],
-            });
+          // Refresh the contents of the folder a dashboard was restored to
+          dispatch(
+            refetchChildren({
+              parentUID: parentFolder,
+              pageSize: PAGE_SIZE,
+            })
+          );
 
-            // Refresh the contents of the folder a dashboard was restored to
-            dispatch(
-              refetchChildren({
-                parentUID: parentFolder,
-                pageSize: PAGE_SIZE,
-              })
-            );
-          }
-
-          return { data: undefined };
+          return { data: { name } };
         } catch (error) {
           return handleRequestError(error);
         }
