@@ -1,3 +1,4 @@
+/* eslint-disable @grafana/i18n/no-translation-top-level */
 import { useSessionStorage } from 'react-use';
 
 import { BusEventWithPayload } from '@grafana/data';
@@ -13,9 +14,9 @@ import {
 
 import { DashboardScene } from '../scene/DashboardScene';
 import { SceneGridRowEditableElement } from '../scene/layout-default/SceneGridRowEditableElement';
-import { redoButtonId, undoButtonID } from '../scene/new-toolbar/RightActions';
 import { EditableDashboardElement, isEditableDashboardElement } from '../scene/types/EditableDashboardElement';
 import { LocalVariableEditableElement } from '../settings/variables/LocalVariableEditableElement';
+import { VariableAdd, VariableAddEditableElement } from '../settings/variables/VariableAddEditableElement';
 import { VariableEditableElement } from '../settings/variables/VariableEditableElement';
 import { VariableSetEditableElement } from '../settings/variables/VariableSetEditableElement';
 import { isSceneVariable } from '../settings/variables/utils';
@@ -60,6 +61,10 @@ export function getEditableElementFor(sceneObj: SceneObject | undefined): Editab
     return new VariableEditableElement(sceneObj);
   }
 
+  if (sceneObj instanceof VariableAdd) {
+    return new VariableAddEditableElement(sceneObj);
+  }
+
   return undefined;
 }
 
@@ -79,6 +84,10 @@ export class ConditionalRenderingChangedEvent extends BusEventWithPayload<SceneO
   static type = 'conditional-rendering-changed';
 }
 
+export class RepeatsUpdatedEvent extends BusEventWithPayload<SceneObject> {
+  static type = 'repeats-updated';
+}
+
 export interface DashboardEditActionEventPayload {
   removedObject?: SceneObject;
   addedObject?: SceneObject;
@@ -191,8 +200,17 @@ export const dashboardEditActions = {
     });
   },
 
+  changeTitle: makeEditAction<DashboardScene, 'title'>({
+    description: t('dashboard.title.action', 'Change dashboard title'),
+    prop: 'title',
+  }),
+  changeDescription: makeEditAction<DashboardScene, 'description'>({
+    description: t('dashboard.description.action', 'Change dashboard description'),
+    prop: 'description',
+  }),
+
   addVariable({ source, addedObject }: AddVariableActionHelperProps) {
-    const varsBeforeAddition = [...source.state.variables];
+    const varsBeforeAddition = [...(source.state.variables ?? [])];
 
     dashboardEditActions.addElement({
       source,
@@ -219,29 +237,38 @@ export const dashboardEditActions = {
       },
     });
   },
+  changeVariableName: makeEditAction<SceneVariable, 'name'>({
+    description: t('dashboard.variable.name.action', 'Change variable name'),
+    prop: 'name',
+  }),
+  changeVariableLabel: makeEditAction<SceneVariable, 'label'>({
+    description: t('dashboard.variable.label.action', 'Change variable label'),
+    prop: 'label',
+  }),
+  changeVariableDescription: makeEditAction<SceneVariable, 'description'>({
+    description: t('dashboard.variable.description.action', 'Change variable description'),
+    prop: 'description',
+  }),
+  changeVariableHideValue({ source, oldValue, newValue }: EditActionProps<SceneVariable, 'hide'>) {
+    const variableSet = source.parent;
+    const variablesBeforeChange =
+      variableSet instanceof SceneVariableSet ? [...(variableSet.state.variables ?? [])] : undefined;
 
-  changeTitle({ source, oldTitle, newTitle }: ChangeTitleActionHelperProps) {
     dashboardEditActions.edit({
-      description: t('dashboard.title.action', 'Change dashboard title'),
+      description: t('dashboard.variable.hide.action', 'Change variable hide option'),
       source,
       perform: () => {
-        source.setState({ title: newTitle });
+        source.setState({ hide: newValue });
+        // Updating the variables set since components that show/hide variables subscribe to the variable set, not the individual variables.
+        if (variableSet instanceof SceneVariableSet) {
+          variableSet.setState({ variables: [...(variableSet.state.variables ?? [])] });
+        }
       },
       undo: () => {
-        source.setState({ title: oldTitle });
-      },
-    });
-  },
-
-  changeDescription({ source, oldDescription, newDescription }: ChangeDescriptionActionHelperProps) {
-    dashboardEditActions.edit({
-      description: t('dashboard.description.action', 'Change dashboard description'),
-      source,
-      perform: () => {
-        source.setState({ description: newDescription });
-      },
-      undo: () => {
-        source.setState({ description: oldDescription });
+        source.setState({ hide: oldValue });
+        if (variableSet instanceof SceneVariableSet && variablesBeforeChange) {
+          variableSet.setState({ variables: variablesBeforeChange });
+        }
       },
     });
   },
@@ -266,6 +293,31 @@ export const dashboardEditActions = {
   },
 };
 
-export function undoRedoWasClicked(e: React.FocusEvent) {
-  return e.relatedTarget && (e.relatedTarget.id === undoButtonID || e.relatedTarget.id === redoButtonId);
+interface MakeEditActionProps<Source extends SceneObject, T extends keyof Source['state']> {
+  description: string;
+  prop: T;
+}
+
+interface EditActionProps<Source extends SceneObject, T extends keyof Source['state']> {
+  source: Source;
+  oldValue: Source['state'][T];
+  newValue: Source['state'][T];
+}
+
+function makeEditAction<Source extends SceneObject, T extends keyof Source['state']>({
+  description,
+  prop,
+}: MakeEditActionProps<Source, T>) {
+  return ({ source, oldValue, newValue }: EditActionProps<Source, T>) => {
+    dashboardEditActions.edit({
+      description,
+      source,
+      perform: () => {
+        source.setState({ [prop]: newValue });
+      },
+      undo: () => {
+        source.setState({ [prop]: oldValue });
+      },
+    });
+  };
 }
