@@ -2,10 +2,10 @@ import { useAsyncFn } from 'react-use';
 
 import { locationUtil } from '@grafana/data';
 import { t } from '@grafana/i18n';
-import { locationService, reportInteraction } from '@grafana/runtime';
+import { locationService } from '@grafana/runtime';
 import { Dashboard } from '@grafana/schema';
-import { Spec as DashboardV2Spec } from '@grafana/schema/dist/esm/schema/dashboard/v2';
-import appEvents from 'app/core/app_events';
+import { Spec as DashboardV2Spec } from '@grafana/schema/apis/dashboard.grafana.app/v2';
+import { appEvents } from 'app/core/app_events';
 import { useAppNotification } from 'app/core/copy/appNotification';
 import { updateDashboardName } from 'app/core/reducers/navBarTree';
 import { useSaveDashboardMutation } from 'app/features/browse-dashboards/api/browseDashboardsAPI';
@@ -15,6 +15,8 @@ import { useDispatch } from 'app/types/store';
 
 import { updateDashboardUidLastUsedDatasource } from '../../dashboard/utils/dashboard';
 import { DashboardScene } from '../scene/DashboardScene';
+import { DashboardInteractions } from '../utils/interactions';
+import { trackDashboardSceneCreatedOrSaved } from '../utils/tracking';
 
 export function useSaveDashboard(isCopy = false) {
   const dispatch = useDispatch();
@@ -55,25 +57,34 @@ export function useSaveDashboard(isCopy = false) {
           throw result.error;
         }
 
-        const resultData = result.data;
+        // result.data is readonly so spreading to allow for slug edits
+        const resultData: typeof result.data = { ...result.data };
+
+        // TODO: use slug from response once implemented
+        // reuse existing slug to avoid "Unsaved changes" modal after save
+        //   due to slugify logic difference between frontend and backend
+        if (!result.data.slug && scene.state.meta.slug) {
+          const slug = scene.state.meta.slug;
+          resultData.slug = slug;
+          resultData.url = `${result.data.url}/${slug}`;
+        }
+
         scene.saveCompleted(saveModel, resultData, options.folderUid);
 
         // important that these happen before location redirect below
         appEvents.publish(new DashboardSavedEvent());
         notifyApp.success(t('dashboard-scene.use-save-dashboard.message-dashboard-saved', 'Dashboard saved'));
 
-        //Update local storage dashboard to handle things like last used datasource
         updateDashboardUidLastUsedDatasource(resultData.uid);
 
         if (isCopy) {
-          reportInteraction('grafana_dashboard_copied', {
-            name: saveModel.title,
-            url: resultData.url,
-          });
+          DashboardInteractions.dashboardCopied({ name: saveModel.title || '', url: resultData.url });
         } else {
-          reportInteraction(`grafana_dashboard_${options.isNew ? 'created' : 'saved'}`, {
-            name: saveModel.title,
-            url: resultData.url,
+          trackDashboardSceneCreatedOrSaved(!!options.isNew, scene, {
+            name: saveModel.title || '',
+            url: resultData.url || '',
+            transformation_counts: scene.getTransformationCounts(saveModel),
+            expression_counts: scene.getExpressionCounts(saveModel),
           });
         }
 
