@@ -15,7 +15,7 @@ import { t } from '@grafana/i18n';
 import { config, locationService } from '@grafana/runtime';
 import { LocalValueVariable, sceneGraph, VizPanel, VizPanelMenu } from '@grafana/scenes';
 import { DataQuery, OptionsWithLegend } from '@grafana/schema';
-import appEvents from 'app/core/app_events';
+import { appEvents } from 'app/core/app_events';
 import { createErrorNotification } from 'app/core/copy/appNotification';
 import { notifyApp } from 'app/core/reducers/appNotification';
 import { contextSrv } from 'app/core/services/context_srv';
@@ -26,7 +26,8 @@ import { getTrackingSource, shareDashboardType } from 'app/features/dashboard/co
 import { InspectTab } from 'app/features/inspector/types';
 import { getScenePanelLinksSupplier } from 'app/features/panel/panellinks/linkSuppliers';
 import { createPluginExtensionsGetter } from 'app/features/plugins/extensions/getPluginExtensions';
-import { pluginExtensionRegistries } from 'app/features/plugins/extensions/registry/setup';
+import { getPluginExtensionRegistries } from 'app/features/plugins/extensions/registry/setup';
+import { PluginExtensionRegistries } from 'app/features/plugins/extensions/registry/types';
 import { GetPluginExtensions } from 'app/features/plugins/extensions/types';
 import { createExtensionSubMenu } from 'app/features/plugins/extensions/utils';
 import { dispatch } from 'app/store/store';
@@ -47,12 +48,12 @@ import { PanelTimeRangeDrawer } from './panel-timerange/PanelTimeRangeDrawer';
 
 let getPluginExtensions: GetPluginExtensions;
 
-function setupGetPluginExtensions() {
+function setupGetPluginExtensions(registries: PluginExtensionRegistries) {
   if (getPluginExtensions) {
     return getPluginExtensions;
   }
 
-  getPluginExtensions = createPluginExtensionsGetter(pluginExtensionRegistries);
+  getPluginExtensions = createPluginExtensionsGetter(registries);
 
   return getPluginExtensions;
 }
@@ -95,6 +96,9 @@ export function panelMenuBehavior(menu: VizPanelMenu) {
           viewPanel: panel.getPathId(),
           editPanel: undefined,
         }),
+        onClick: () => {
+          DashboardInteractions.panelActionClicked('view', getPanelIdForVizPanel(panel), 'panel');
+        },
       });
     }
 
@@ -106,6 +110,9 @@ export function panelMenuBehavior(menu: VizPanelMenu) {
         iconClassName: 'edit',
         shortcut: 'e',
         href: getEditPanelUrl(getPanelIdForVizPanel(panel)),
+        onClick: () => {
+          DashboardInteractions.panelActionClicked('edit', getPanelIdForVizPanel(panel), 'panel');
+        },
       });
     }
 
@@ -187,6 +194,7 @@ export function panelMenuBehavior(menu: VizPanelMenu) {
         text: t('panel.header-menu.duplicate', `Duplicate`),
         iconClassName: 'file-copy-alt',
         onClick: () => {
+          DashboardInteractions.panelActionClicked('duplicate', getPanelIdForVizPanel(panel), 'panel');
           dashboard.duplicatePanel(panel);
         },
         shortcut: 'p d',
@@ -198,6 +206,7 @@ export function panelMenuBehavior(menu: VizPanelMenu) {
         text: t('panel.header-menu.copy', `Copy`),
         iconClassName: 'copy',
         onClick: () => {
+          DashboardInteractions.panelActionClicked('copy', getPanelIdForVizPanel(panel), 'panel');
           dashboard.copyPanel(panel);
         },
       });
@@ -292,7 +301,8 @@ export function panelMenuBehavior(menu: VizPanelMenu) {
       });
     }
 
-    setupGetPluginExtensions();
+    const registries = await getPluginExtensionRegistries();
+    setupGetPluginExtensions(registries);
 
     const { extensions } = getPluginExtensions({
       extensionPointId: PluginExtensionPoints.DashboardPanelMenu,
@@ -337,6 +347,48 @@ export function panelMenuBehavior(menu: VizPanelMenu) {
       }
     }
 
+    if (panel.state.pluginId === 'timeseries' && config.featureToggles.panelStyleActions && dashboard.state.isEditing) {
+      const stylesSubMenu: PanelMenuItem[] = [];
+
+      stylesSubMenu.push({
+        text: t('panel.header-menu.copy-styles', `Copy styles`),
+        iconClassName: 'copy',
+        onClick: () => {
+          DashboardInteractions.panelStylesMenuClicked(
+            'copy',
+            panel.state.pluginId,
+            getPanelIdForVizPanel(panel) ?? -1
+          );
+          dashboard.copyPanelStyles(panel);
+        },
+      });
+
+      if (DashboardScene.hasPanelStylesToPaste('timeseries')) {
+        stylesSubMenu.push({
+          text: t('panel.header-menu.paste-styles', `Paste styles`),
+          iconClassName: 'clipboard-alt',
+          onClick: () => {
+            DashboardInteractions.panelStylesMenuClicked(
+              'paste',
+              panel.state.pluginId,
+              getPanelIdForVizPanel(panel) ?? -1
+            );
+            dashboard.pastePanelStyles(panel);
+          },
+        });
+      }
+
+      items.push({
+        type: 'submenu',
+        text: t('panel.header-menu.styles', `Styles`),
+        iconClassName: 'palette',
+        subMenu: stylesSubMenu,
+        onClick: (e) => {
+          e.preventDefault();
+        },
+      });
+    }
+
     if (moreSubMenu.length) {
       items.push({
         type: 'submenu',
@@ -359,6 +411,7 @@ export function panelMenuBehavior(menu: VizPanelMenu) {
         text: t('panel.header-menu.remove', `Remove`),
         iconClassName: 'trash-alt',
         onClick: () => {
+          DashboardInteractions.panelActionClicked('delete', getPanelIdForVizPanel(panel), 'panel');
           onRemovePanel(dashboard, panel);
         },
         shortcut: 'p r',
