@@ -15,3 +15,15 @@ export function findAllGridTypes(layout: DashboardLayoutManager): string[] {
 
   return [];
 }
+
+export function containsTabsLayout(layout: DashboardLayoutManager): boolean {
+  if (layout instanceof TabsLayoutManager) {
+    return true;
+  }
+
+  if (layout instanceof RowsLayoutManager) {
+    return layout.state.rows.some((row) => containsTabsLayout(row.getLayout()));
+  }
+
+  return false;
+}
