@@ -1,5 +1,5 @@
 import { Registry, RegistryItem } from '@grafana/data';
-import { Spec as DashboardV2Spec } from '@grafana/schema/dist/esm/schema/dashboard/v2';
+import { Spec as DashboardV2Spec } from '@grafana/schema/apis/dashboard.grafana.app/v2';
 
 import { DashboardLayoutManager } from '../../scene/types/DashboardLayoutManager';
 
