@@ -1,4 +1,4 @@
-import { VariableRefresh } from '@grafana/data';
+import { VariableRefresh, PanelData, LoadingState, toDataFrame, FieldType, getDefaultTimeRange } from '@grafana/data';
 import { config } from '@grafana/runtime';
 import {
   AdHocFiltersVariable,
@@ -18,6 +18,8 @@ import {
   VizPanel,
   SceneDataQuery,
   SceneQueryRunner,
+  SceneDataTransformer,
+  SceneDataNode,
   sceneUtils,
   dataLayers,
 } from '@grafana/scenes';
@@ -25,13 +27,15 @@ import {
   DashboardCursorSync as DashboardCursorSyncV1,
   VariableHide as VariableHideV1,
   VariableSort as VariableSortV1,
-} from '@grafana/schema/dist/esm/index.gen';
+} from '@grafana/schema';
 import {
   GridLayoutSpec,
   AutoGridLayoutSpec,
   RowsLayoutSpec,
   TabsLayoutSpec,
-} from '@grafana/schema/dist/esm/schema/dashboard/v2alpha1/types.spec.gen';
+  defaultDataQueryKind,
+} from '@grafana/schema/apis/dashboard.grafana.app/v2';
+import { GrafanaQueryType } from 'app/plugins/datasource/grafana/types';
 
 import { DashboardEditPane } from '../edit-pane/DashboardEditPane';
 import { DashboardAnnotationsDataLayer } from '../scene/DashboardAnnotationsDataLayer';
@@ -57,6 +61,7 @@ import {
   validateDashboardSchemaV2,
   getDataQueryKind,
   getAutoAssignedDSRef,
+  getVizPanelQueries,
 } from './transformSceneToSaveModelSchemaV2';
 
 // Mock dependencies
@@ -107,33 +112,29 @@ jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
   config: {
     ...jest.requireActual('@grafana/runtime').config,
-    bootData: {
-      settings: {
-        defaultDatasource: 'loki',
-        datasources: {
-          Prometheus: {
-            name: 'Prometheus',
-            meta: { id: 'prometheus' },
-            type: 'datasource',
-          },
-          '-- Grafana --': {
-            name: 'Grafana',
-            meta: { id: 'grafana' },
-            type: 'datasource',
-          },
-          loki: {
-            name: 'Loki',
-            meta: {
-              id: 'loki',
-              name: 'Loki',
-              type: 'datasource',
-              info: { version: '1.0.0' },
-              module: 'app/plugins/datasource/loki/module',
-              baseUrl: '/plugins/loki',
-            },
-            type: 'datasource',
-          },
+    defaultDatasource: 'loki',
+    datasources: {
+      Prometheus: {
+        name: 'Prometheus',
+        meta: { id: 'prometheus' },
+        type: 'prometheus',
+      },
+      '-- Grafana --': {
+        name: 'Grafana',
+        meta: { id: 'grafana' },
+        type: 'grafana',
+      },
+      loki: {
+        name: 'Loki',
+        meta: {
+          id: 'loki',
+          name: 'Loki',
+          type: 'datasource',
+          info: { version: '1.0.0' },
+          module: 'app/plugins/datasource/loki/module',
+          baseUrl: '/plugins/loki',
         },
+        type: 'loki',
       },
     },
   },
@@ -157,7 +158,6 @@ describe('transformSceneToSaveModelSchemaV2', () => {
     // with all the possible properties set
     dashboardScene = setupDashboardScene({
       $data: new DashboardDataLayerSet({ annotationLayers: createAnnotationLayers() }),
-      id: 1,
       title: 'Test Dashboard',
       description: 'Test Description',
       preload: true,
@@ -285,6 +285,7 @@ describe('transformSceneToSaveModelSchemaV2', () => {
             sort: VariableSortV1.alphabeticalDesc,
             refresh: VariableRefresh.onDashboardLoad,
             regex: 'regex1',
+            regexApplyTo: 'value',
             allValue: '*',
             includeAll: true,
             isMulti: true,
@@ -410,9 +411,46 @@ describe('transformSceneToSaveModelSchemaV2', () => {
     expect(result).toMatchSnapshot();
 
     // Check that the annotation layers are correctly transformed
-    expect(result.annotations).toHaveLength(3);
-    // Check annotation layer 3 without initial data source isn't updated with runtime default
-    expect(result.annotations?.[2].spec.datasource?.type).toBe(undefined);
+    expect(result.annotations).toHaveLength(2);
+  });
+
+  it('should transform links with placement property', () => {
+    const sceneWithPlacementLink = new DashboardScene({
+      links: [
+        {
+          title: 'Link in Controls Menu',
+          url: 'http://test.com',
+          type: 'link',
+          placement: 'inControlsMenu',
+          asDropdown: false,
+          icon: '',
+          includeVars: false,
+          keepTime: false,
+          tags: [],
+          targetBlank: false,
+          tooltip: '',
+        },
+        {
+          title: 'Link without placement',
+          url: 'http://test2.com',
+          type: 'link',
+          asDropdown: false,
+          icon: '',
+          includeVars: false,
+          keepTime: false,
+          tags: [],
+          targetBlank: false,
+          tooltip: '',
+        },
+      ],
+    });
+
+    const result = transformSceneToSaveModelSchemaV2(sceneWithPlacementLink);
+
+    expect(result.links).toBeDefined();
+    expect(result.links).toHaveLength(2);
+    expect(result.links![0]).toHaveProperty('placement', 'inControlsMenu');
+    expect(result.links![1]).not.toHaveProperty('placement');
   });
 
   it('should transform the minimum scene to save model schema v2', () => {
@@ -435,6 +473,11 @@ describe('transformSceneToSaveModelSchemaV2', () => {
         datasource: { uid: 'prometheus', type: 'prometheus' },
       };
 
+      const queryWithOnlyDSType: SceneDataQuery = {
+        refId: 'C',
+        datasource: { type: 'prometheus' },
+      };
+
       // Mock query runner with runtime-resolved datasource
       const queryRunner = new SceneQueryRunner({
         queries: [queryWithoutDS, queryWithDS],
@@ -442,7 +485,7 @@ describe('transformSceneToSaveModelSchemaV2', () => {
       });
 
       // Get a reference to the DS references mapping
-      const dsReferencesMap = new Set(['A']);
+      const dsReferencesMap = new Map<string, string | undefined>([['A', undefined]]);
 
       // Test the query without DS originally - should return undefined
       const resultA = getPersistedDSFor(queryWithoutDS, dsReferencesMap, 'query', queryRunner);
@@ -452,13 +495,17 @@ describe('transformSceneToSaveModelSchemaV2', () => {
       const resultB = getPersistedDSFor(queryWithDS, dsReferencesMap, 'query', queryRunner);
       expect(resultB).toEqual({ uid: 'prometheus', type: 'prometheus' });
 
+      // Test the query with only type defined - should return the type
+      const resultC = getPersistedDSFor(queryWithOnlyDSType, dsReferencesMap, 'query', queryRunner);
+      expect(resultC).toEqual({ type: 'prometheus' });
+
       // Test a query with no DS originally but not in the mapping - should get the runner's datasource
       const queryNotInMapping: SceneDataQuery = {
-        refId: 'C',
+        refId: 'D',
         // No datasource, but not in mapping
       };
-      const resultC = getPersistedDSFor(queryNotInMapping, dsReferencesMap, 'query', queryRunner);
-      expect(resultC).toEqual({ uid: 'default-ds', type: 'default' });
+      const resultD = getPersistedDSFor(queryNotInMapping, dsReferencesMap, 'query', queryRunner);
+      expect(resultD).toEqual({ uid: 'default-ds', type: 'default' });
     });
   });
 
@@ -476,8 +523,14 @@ describe('transformSceneToSaveModelSchemaV2', () => {
         datasource: { uid: 'prometheus', type: 'prometheus' },
       });
 
+      // Variable with only type defined
+      const variableWithOnlyDSType = new QueryVariable({
+        name: 'C',
+        datasource: { type: 'prometheus' },
+      });
+
       // Get a reference to the DS references mapping
-      const dsReferencesMap = new Set(['A']);
+      const dsReferencesMap = new Map<string, string | undefined>([['A', undefined]]);
 
       // Test the variable without DS originally - should return undefined
       const resultA = getPersistedDSFor(variableWithoutDS, dsReferencesMap, 'variable');
@@ -487,13 +540,17 @@ describe('transformSceneToSaveModelSchemaV2', () => {
       const resultB = getPersistedDSFor(variableWithDS, dsReferencesMap, 'variable');
       expect(resultB).toEqual({ uid: 'prometheus', type: 'prometheus' });
 
-      // Test a variable with no DS originally but not in the mapping - should get empty object
+      // Test the variable with only type defined - should return the type
+      const resultC = getPersistedDSFor(variableWithOnlyDSType, dsReferencesMap, 'variable');
+      expect(resultC).toEqual({ type: 'prometheus' });
+
+      // Test a variable with no DS originally but not in the mapping - should return undefined
       const variableNotInMapping = new QueryVariable({
-        name: 'C',
+        name: 'D',
         // No datasource, but not in mapping
       });
-      const resultC = getPersistedDSFor(variableNotInMapping, dsReferencesMap, 'variable');
-      expect(resultC).toEqual({});
+      const resultD = getPersistedDSFor(variableNotInMapping, dsReferencesMap, 'variable');
+      expect(resultD).toBeUndefined();
     });
   });
 
@@ -562,16 +619,8 @@ describe('transformSceneToSaveModelSchemaV2', () => {
         name: 'annotation-with-options',
         enable: true,
         iconColor: 'red',
-        legacyOptions: {
-          expr: 'rate(http_requests_total[5m])',
-          queryType: 'range',
-          legendFormat: '{{method}} {{endpoint}}',
-          useValueAsTime: true,
-        },
-        // Some other properties that aren't in the annotation spec
-        // and should be moved to options
-        customProp1: 'value1',
-        customProp2: 'value2',
+        customProp1: true,
+        customProp2: 'test',
       },
       name: 'layerWithOptions',
       isEnabled: true,
@@ -593,19 +642,11 @@ describe('transformSceneToSaveModelSchemaV2', () => {
     expect(result.annotations.length).toBe(1);
     expect(result.annotations[0].spec.legacyOptions).toBeDefined();
     expect(result.annotations[0].spec.legacyOptions).toEqual({
-      expr: 'rate(http_requests_total[5m])',
-      queryType: 'range',
-      legendFormat: '{{method}} {{endpoint}}',
-      useValueAsTime: true,
-      customProp1: 'value1',
-      customProp2: 'value2',
+      customProp1: true,
+      customProp2: 'test',
     });
 
     // Ensure these properties are not at the root level
-    expect(result).not.toHaveProperty('annotations[0].spec.expr');
-    expect(result).not.toHaveProperty('annotations[0].spec.queryType');
-    expect(result).not.toHaveProperty('annotations[0].spec.legendFormat');
-    expect(result).not.toHaveProperty('annotations[0].spec.useValueAsTime');
     expect(result).not.toHaveProperty('annotations[0].spec.customProp1');
     expect(result).not.toHaveProperty('annotations[0].spec.customProp2');
   });
@@ -628,6 +669,11 @@ describe('getElementDatasource', () => {
       refId: 'A',
     };
 
+    const queryWithOnlyType: SceneDataQuery = {
+      refId: 'C',
+      datasource: { type: 'prometheus' },
+    };
+
     // Mock query runner
     const queryRunner = new SceneQueryRunner({
       queries: [queryWithoutDS, queryWithDS],
@@ -636,9 +682,9 @@ describe('getElementDatasource', () => {
 
     // Mock dsReferencesMapping
     const dsReferencesMapping = {
-      panels: new Map(new Set([['panel-1', new Set<string>(['A'])]])),
-      variables: new Set<string>(),
-      annotations: new Set<string>(),
+      panels: new Map<string, Map<string, string>>([['panel-1', new Map<string, string>([['A', '']])]]),
+      variables: new Map<string, string>(),
+      annotations: new Map<string, string>(),
     };
 
     // Call the function with the panel and query with DS
@@ -648,6 +694,16 @@ describe('getElementDatasource', () => {
     // Call the function with the panel and query without DS
     const resultWithoutDS = getElementDatasource(vizPanel, queryWithoutDS, 'panel', queryRunner, dsReferencesMapping);
     expect(resultWithoutDS).toBeUndefined();
+
+    // Call the function with the panel and query with only type
+    const resultWithOnlyType = getElementDatasource(
+      vizPanel,
+      queryWithOnlyType,
+      'panel',
+      queryRunner,
+      dsReferencesMapping
+    );
+    expect(resultWithOnlyType).toEqual({ type: 'prometheus' });
   });
 
   it('should handle variable datasources correctly', () => {
@@ -673,9 +729,9 @@ describe('getElementDatasource', () => {
 
     // Mock dsReferencesMapping
     const dsReferencesMapping = {
-      panels: new Map(new Set([['panel-1', new Set<string>(['A'])]])),
-      variables: new Set<string>(['A']),
-      annotations: new Set<string>(),
+      panels: new Map<string, Map<string, string>>([['panel-1', new Map<string, string>([['A', '']])]]),
+      variables: new Map<string, string>([['A', '']]),
+      annotations: new Map<string, string>(),
     };
 
     // Call the function with variables
@@ -762,11 +818,25 @@ describe('getElementDatasource', () => {
       iconColor: 'blue',
     };
 
+    // Create an annotation query with only type defined
+    const annotationLayerWithOnlyType = new dataLayers.AnnotationsDataLayer({
+      name: 'Annotation with only datasource type',
+      isEnabled: true,
+      isHidden: false,
+      query: {
+        name: 'Test Annotation',
+        enable: true,
+        hide: false,
+        iconColor: 'blue',
+        datasource: { type: 'prometheus' },
+      },
+    });
+
     // Mock dsReferencesMapping
     const dsReferencesMapping = {
-      panels: new Map([['panel-1', new Set(['A'])]]),
-      variables: new Set<string>(),
-      annotations: new Set<string>(['No DS Annotation']),
+      panels: new Map<string, Map<string, string>>([['panel-1', new Map<string, string>([['A', '']])]]),
+      variables: new Map<string, string>(),
+      annotations: new Map<string, string>(),
     };
 
     // Test with annotation that has datasource defined
@@ -788,6 +858,16 @@ describe('getElementDatasource', () => {
       dsReferencesMapping
     );
     expect(resultWithoutDS).toBeUndefined();
+
+    // Test with annotation that has only type defined
+    const resultWithOnlyType = getElementDatasource(
+      annotationLayer,
+      annotationLayerWithOnlyType.state.query,
+      'annotation',
+      undefined,
+      dsReferencesMapping
+    );
+    expect(resultWithOnlyType).toEqual({ type: 'prometheus' });
   });
 
   it('should handle invalid input combinations', () => {
@@ -834,9 +914,149 @@ describe('getElementDatasource', () => {
   });
 });
 
+describe('getVizPanelQueries', () => {
+  it('should handle panel query datasources correctly', () => {
+    const queryWithDS: SceneDataQuery = {
+      refId: 'B',
+      datasource: { uid: 'prometheus-uid', type: 'prometheus' },
+    };
+
+    const queryWithoutDS: SceneDataQuery = {
+      refId: 'A',
+    };
+
+    // Mock query runner
+    const queryRunner = new SceneQueryRunner({
+      queries: [queryWithoutDS, queryWithDS],
+      datasource: { uid: 'default-ds', type: 'default' },
+    });
+    // Create test elements
+    const vizPanel = new VizPanel({
+      key: 'panel-1',
+      pluginId: 'timeseries',
+      $data: queryRunner,
+    });
+
+    // Mock dsReferencesMapping
+    const dsReferencesMapping = {
+      panels: new Map<string, Map<string, string>>([['panel-1', new Map<string, string>([['A', '']])]]),
+      variables: new Map<string, string>(),
+      annotations: new Map<string, string>(),
+    };
+
+    const result = getVizPanelQueries(vizPanel, dsReferencesMapping);
+    expect(result.length).toBe(2);
+    expect(result[0].spec.query.kind).toBe('DataQuery');
+    expect(result[0].spec.query.datasource).toBeUndefined(); // ignore datasource if it wasn't provided
+    expect(result[0].spec.query.group).toBe(defaultDataQueryKind().group); // this is a default query that contains only refId and therefore group should be the default group
+    expect(result[0].spec.query.version).toBe('v0');
+
+    expect(result[1].spec.query.kind).toBe('DataQuery');
+    expect(result[1].spec.query.datasource?.name).toBe('prometheus-uid');
+    expect(result[1].spec.query.group).toBe('prometheus');
+    expect(result[1].spec.query.version).toBe('v0');
+  });
+
+  describe('snapshot mode', () => {
+    it('should return empty queries when isSnapshot is true but panel has no data provider', () => {
+      const vizPanel = new VizPanel({
+        key: 'panel-1',
+        pluginId: 'timeseries',
+        // No $data provider
+      });
+
+      const result = getVizPanelQueries(vizPanel, undefined, true);
+      expect(result).toEqual([]);
+    });
+
+    it('should create snapshot query from SceneQueryRunner data when isSnapshot is true', () => {
+      const mockDataFrame = toDataFrame({
+        name: 'test-series',
+        fields: [
+          { name: 'time', type: FieldType.time, values: [1000, 2000, 3000] },
+          { name: 'value', type: FieldType.number, values: [1, 2, 3] },
+        ],
+      });
+
+      const panelData: PanelData = {
+        series: [mockDataFrame],
+        state: LoadingState.Done,
+        timeRange: getDefaultTimeRange(),
+      };
+
+      const queryRunner = new SceneQueryRunner({
+        queries: [],
+        data: panelData,
+      });
+
+      const vizPanel = new VizPanel({
+        key: 'panel-1',
+        pluginId: 'timeseries',
+        $data: queryRunner,
+      });
+
+      const result = getVizPanelQueries(vizPanel, undefined, true);
+
+      expect(result).toHaveLength(1);
+      expect(result[0].kind).toBe('PanelQuery');
+      expect(result[0].spec.refId).toBe('A');
+      expect(result[0].spec.hidden).toBe(false);
+      expect(result[0].spec.query.kind).toBe('DataQuery');
+      expect(result[0].spec.query.version).toBe(defaultDataQueryKind().version);
+      expect(result[0].spec.query.group).toBe('grafana');
+      expect(result[0].spec.query.datasource).toEqual({ name: 'grafana' });
+      expect(result[0].spec.query.spec.queryType).toBe(GrafanaQueryType.Snapshot);
+      expect(result[0].spec.query.spec.snapshot).toBeDefined();
+      expect(result[0].spec.query.spec.snapshot).toHaveLength(1);
+      expect(result[0].spec.query.spec.snapshot[0].schema?.fields).toBeDefined();
+    });
+
+    it('should create snapshot query from SceneDataTransformer data when isSnapshot is true', () => {
+      const mockDataFrame = toDataFrame({
+        name: 'transformed-series',
+        fields: [
+          { name: 'time', type: FieldType.time, values: [1000, 2000] },
+          { name: 'transformed', type: FieldType.number, values: [10, 20] },
+        ],
+      });
+
+      const panelData: PanelData = {
+        series: [mockDataFrame],
+        state: LoadingState.Done,
+        timeRange: getDefaultTimeRange(),
+      };
+
+      const dataNode = new SceneDataNode({
+        data: panelData,
+      });
+
+      const dataTransformer = new SceneDataTransformer({
+        $data: dataNode,
+        transformations: [],
+      });
+
+      const vizPanel = new VizPanel({
+        key: 'panel-1',
+        pluginId: 'timeseries',
+        $data: dataTransformer,
+      });
+
+      const result = getVizPanelQueries(vizPanel, undefined, true);
+
+      expect(result).toHaveLength(1);
+      expect(result[0].kind).toBe('PanelQuery');
+      expect(result[0].spec.query.kind).toBe('DataQuery');
+      expect(result[0].spec.query.spec.queryType).toBe(GrafanaQueryType.Snapshot);
+      expect(result[0].spec.query.spec.snapshot).toBeDefined();
+      expect(result[0].spec.query.spec.snapshot).toHaveLength(1);
+      // Verify it gets data from the nested $data (SceneDataNode) not the transformer
+      expect(result[0].spec.query.spec.snapshot[0].schema?.fields).toBeDefined();
+    });
+  });
+});
+
 function getMinimalSceneState(body: DashboardLayoutManager): Partial<DashboardSceneState> {
   return {
-    id: 1,
     title: 'Test Dashboard',
     description: 'Test Description',
     preload: true,
@@ -1065,18 +1285,6 @@ function createAnnotationLayers() {
       isEnabled: true,
       isHidden: true,
     }),
-    // this could happen if a dahboard was created from code and the datasource was not defined
-    new DashboardAnnotationsDataLayer({
-      key: 'layer3',
-      query: {
-        name: 'query3',
-        enable: true,
-        iconColor: 'green',
-      },
-      name: 'layer3',
-      isEnabled: true,
-      isHidden: true,
-    }),
   ];
 }
 
