@@ -14,7 +14,13 @@ type DashboardLibraryTrackingInfo = {
 export const DashboardInteractions = {
   // Dashboard interactions:
   dashboardInitialized: (
-    properties: { theme: undefined; duration: number | undefined; isScene: boolean } & Partial<DashboardTrackingInfo> &
+    properties: {
+      theme: undefined;
+      duration: number | undefined;
+      isScene: boolean;
+      hasEditPermissions?: boolean;
+      hasSavePermissions?: boolean;
+    } & Partial<DashboardTrackingInfo> &
       Partial<DynamicDashboardsTrackingInformation> &
       Partial<{ version_before_migration: number | undefined }>
   ) => {
@@ -28,11 +34,19 @@ export const DashboardInteractions = {
   dashboardCreatedOrSaved: (
     isNew: boolean | undefined,
     properties:
-      | ({ name: string; url: string } & DashboardLibraryTrackingInfo)
+      | ({
+          name: string;
+          url: string;
+          uid: string;
+          numPanels: number;
+          numRows: number;
+        } & DashboardLibraryTrackingInfo)
       | ({
           name: string;
           url: string;
           numPanels: number;
+          numTabs: number;
+          numRows: number;
           uid: string;
           conditionalRenderRules: number;
           autoLayoutCount: number;
@@ -73,11 +87,46 @@ export const DashboardInteractions = {
     reportDashboardInteraction('add_variable_button_clicked', properties);
   },
 
+  // dashboards_new_variable_type_selected
+  // when a user selects a variable type when creating a new variable
+  newVariableTypeSelected: (properties: { type: string }) => {
+    reportDashboardInteraction('new_variable_type_selected', properties);
+  },
+
+  // dashboards_delete_variable_button_clicked
+  // when a user deletes a variable
+  deleteVariableButtonClicked: (properties: { type: string }) => {
+    reportDashboardInteraction('delete_variable_button_clicked', properties);
+  },
+
+  // dashboards_variables_reordered
+  // when a user drags and drops a variable in the content outline
+  variablesReordered: (properties: { source: 'edit_pane' }) => {
+    reportDashboardInteraction('variables_reordered', properties);
+  },
+
+  panelActionClicked(
+    item: 'configure' | 'configure_dropdown' | 'edit' | 'copy' | 'duplicate' | 'delete' | 'view',
+    id: number,
+    source: 'panel' | 'edit_pane' | 'keyboard'
+  ) {
+    reportDashboardInteraction('panel_action_clicked', { item, id, source });
+  },
+
+  // Panel styles copy/paste interactions
+  panelStylesMenuClicked(action: 'copy' | 'paste', panelType: string, panelId: number, error?: boolean) {
+    reportDashboardInteraction('panel_styles_menu_clicked', { action, panelType, panelId, error });
+  },
+
   // Dashboard edit item actions
   // dashboards_edit_action_clicked: when user adds or removes an item in edit mode
   // props: { item: string } - item is one of: add_panel, group_row, group_tab, ungroup, paste_panel, remove_row, remove_tab
-  trackAddPanelClick() {
-    reportDashboardInteraction('edit_action_clicked', { item: 'add_panel' });
+  trackAddPanelClick(
+    source: 'sidebar' | 'canvas' = 'canvas',
+    target?: 'row' | 'tab' | 'dashboard',
+    action: 'drop' | 'click' = 'click'
+  ) {
+    reportDashboardInteraction('edit_action_clicked', { item: 'add_panel', source, target, action });
   },
   trackGroupRowClick() {
     reportDashboardInteraction('edit_action_clicked', { item: 'group_row' });
@@ -225,6 +274,12 @@ export const DashboardInteractions = {
   copyImageUrlClicked: (properties?: Record<string, unknown>) => {
     reportDashboardInteraction('dashboard_image_url_copied', properties);
   },
+
+  // move item interactions
+  trackMoveItem: (item: 'panel' | 'row' | 'tab', action: 'drag' | 'drop', context: { isCrossLayout: boolean }) => {
+    const properties = { item, action, context };
+    reportDashboardInteraction('move_item', properties);
+  },
 };
 
 const reportDashboardInteraction = (
