@@ -1,7 +1,6 @@
-import { TypedVariableModel } from '@grafana/data';
+import { MetricFindValue, TypedVariableModel, AnnotationQuery } from '@grafana/data';
 import { config } from '@grafana/runtime';
 import {
-  AnnotationQuery,
   DataQuery,
   DataSourceRef,
   Panel,
@@ -20,7 +19,6 @@ import {
   DataLink,
   DatasourceVariableKind,
   defaultSpec as defaultDashboardV2Spec,
-  defaultFieldConfigSource,
   defaultTimeSettingsSpec,
   PanelQueryKind,
   QueryVariableKind,
@@ -35,14 +33,19 @@ import {
   IntervalVariableKind,
   TextVariableKind,
   GroupByVariableKind,
+  SwitchVariableKind,
   LibraryPanelKind,
   PanelKind,
   GridLayoutItemKind,
   defaultDataQueryKind,
   RowsLayoutRowKind,
   GridLayoutKind,
-} from '@grafana/schema/dist/esm/schema/dashboard/v2';
-import { DashboardLink, DataTransformerConfig } from '@grafana/schema/src/raw/dashboard/x/dashboard_types.gen';
+  defaultDashboardLinkType,
+  defaultDashboardLink,
+  defaultFieldConfigSource,
+  defaultPanelQueryKind,
+} from '@grafana/schema/apis/dashboard.grafana.app/v2';
+import { DashboardLink, DataTransformerConfig } from '@grafana/schema/dist/esm/raw/dashboard/x/Dashboard_types.gen';
 import { isWeekStart, WeekStart } from '@grafana/ui';
 import {
   AnnoKeyCreatedBy,
@@ -182,9 +185,11 @@ export function ensureV2Response(
     tags: dashboard.tags ?? [],
     cursorSync: transformCursorSynctoEnum(dashboard.graphTooltip),
     preload: dashboard.preload || dashboardDefaults.preload,
-    liveNow: dashboard.liveNow,
-    editable: dashboard.editable,
-    revision: dashboard.revision,
+    // transformSceneToSaveModelSchemaV2.ts sets liveNow and editable to default values if they are not set
+    // so we are matching that behavior here so conversion pipeline tests like ResponseTransformersToBackend.test.ts pass
+    liveNow: dashboard.liveNow ?? Boolean(dashboardDefaults.liveNow),
+    editable: dashboard.editable ?? dashboardDefaults.editable,
+    ...(dashboard.revision !== undefined && { revision: dashboard.revision }),
     timeSettings: {
       from: dashboard.time?.from || timeSettingsDefaults.from,
       to: dashboard.time?.to || timeSettingsDefaults.to,
@@ -193,11 +198,25 @@ export function ensureV2Response(
       autoRefreshIntervals: dashboard.timepicker?.refresh_intervals || timeSettingsDefaults.autoRefreshIntervals,
       fiscalYearStartMonth: dashboard.fiscalYearStartMonth || timeSettingsDefaults.fiscalYearStartMonth,
       hideTimepicker: dashboard.timepicker?.hidden || timeSettingsDefaults.hideTimepicker,
-      quickRanges: dashboard.timepicker?.quick_ranges,
-      weekStart: getWeekStart(dashboard.weekStart, timeSettingsDefaults.weekStart),
-      nowDelay: dashboard.timepicker?.nowDelay || timeSettingsDefaults.nowDelay,
+      ...(dashboard.timepicker?.quick_ranges !== undefined && { quickRanges: dashboard.timepicker.quick_ranges }),
+      ...(dashboard.weekStart !== undefined && {
+        weekStart: getWeekStart(dashboard.weekStart, timeSettingsDefaults.weekStart),
+      }),
+      ...(dashboard.timepicker?.nowDelay !== undefined && { nowDelay: dashboard.timepicker.nowDelay }),
     },
-    links: dashboard.links || [],
+    links: (dashboard.links || []).map((link) => ({
+      title: link.title ?? defaultDashboardLink().title,
+      url: link.url ?? defaultDashboardLink().url,
+      type: link.type ?? defaultDashboardLinkType(),
+      icon: link.icon ?? defaultDashboardLink().icon,
+      tooltip: link.tooltip ?? defaultDashboardLink().tooltip,
+      tags: link.tags ?? defaultDashboardLink().tags,
+      asDropdown: link.asDropdown ?? defaultDashboardLink().asDropdown,
+      keepTime: link.keepTime ?? defaultDashboardLink().keepTime,
+      includeVars: link.includeVars ?? defaultDashboardLink().includeVars,
+      targetBlank: link.targetBlank ?? defaultDashboardLink().targetBlank,
+      ...(link.placement !== undefined && { placement: link.placement }),
+    })),
     annotations,
     variables,
     elements,
@@ -232,6 +251,7 @@ export function ensureV1Response(
         uid: dashboard.metadata.name,
         k8s: dashboard.metadata,
         version: dashboard.metadata.generation,
+        publicDashboardEnabled: dashboard.access.isPublic,
       },
       dashboard: spec,
     };
@@ -253,6 +273,7 @@ export function ensureV1Response(
         canShare: dashboard.access.canShare,
         canStar: dashboard.access.canStar,
         annotationsPermissions: dashboard.access.annotationsPermissions,
+        publicDashboardEnabled: dashboard.access.isPublic,
       },
       dashboard: transformDashboardV2SpecToV1(spec, dashboard.metadata),
     };
@@ -387,7 +408,7 @@ function buildRowKind(p: RowPanel, elements: GridLayoutItemKind[]): RowsLayoutRo
     spec: {
       collapse: p.collapsed,
       title: p.title ?? '',
-      repeat: p.repeat ? { value: p.repeat, mode: 'variable' } : undefined,
+      ...(p.repeat ? { repeat: { value: p.repeat, mode: 'variable' } } : {}),
       layout: {
         kind: 'GridLayout',
         spec: {
@@ -406,9 +427,16 @@ function buildGridItemKind(p: Panel, elementName: string, yOverride?: number): G
       y: yOverride ?? p.gridPos!.y,
       width: p.gridPos!.w,
       height: p.gridPos!.h,
-      repeat: p.repeat
-        ? { value: p.repeat, mode: 'variable', direction: p.repeatDirection, maxPerRow: p.maxPerRow }
-        : undefined,
+      ...(p.repeat
+        ? {
+            repeat: {
+              value: p.repeat,
+              mode: 'variable',
+              ...(p.repeatDirection !== undefined && { direction: p.repeatDirection }),
+              ...(p.maxPerRow !== undefined && { maxPerRow: p.maxPerRow }),
+            },
+          }
+        : {}),
       element: {
         kind: 'ElementReference',
         name: elementName!,
@@ -452,24 +480,30 @@ function getDefaultDatasourceType() {
 }
 
 export function getDefaultDatasource(): DataSourceRef {
-  const configDefaultDS = getDefaultDataSourceRef() ?? { type: 'grafana', uid: '-- Grafana --' };
+  const defaultDataSourceRef = getDefaultDataSourceRef() ?? { type: 'grafana', uid: '-- Grafana --' };
 
-  if (configDefaultDS.uid && !configDefaultDS.apiVersion) {
+  if (defaultDataSourceRef.uid && !defaultDataSourceRef.apiVersion) {
     // get api version from config
-    const dsInstance = config.datasources[configDefaultDS.uid];
-    configDefaultDS.apiVersion = dsInstance.apiVersion ?? undefined;
+    const defaultDatasource = config.defaultDatasource;
+    const dsInstance = config.datasources[defaultDatasource];
+    defaultDataSourceRef.apiVersion = dsInstance.apiVersion ?? undefined;
   }
 
   return {
-    apiVersion: configDefaultDS.apiVersion,
-    type: configDefaultDS.type,
-    uid: configDefaultDS.uid,
+    apiVersion: defaultDataSourceRef.apiVersion,
+    type: defaultDataSourceRef.type,
+    uid: defaultDataSourceRef.uid,
   };
 }
 
-export function getPanelQueries(targets: DataQuery[], panelDatasource: DataSourceRef): PanelQueryKind[] {
+export function getPanelQueries(targets: DataQuery[], panelDatasource: DataSourceRef): PanelQueryKind[] | undefined {
   return targets.map((t) => {
     const { refId, hide, datasource, ...query } = t;
+    // Check if target datasource is empty object {} (no keys), treat it as missing
+    // and fall through to use panel datasource (matches backend behavior)
+    const targetDs = t.datasource;
+    const isEmptyDatasourceObject = targetDs && typeof targetDs === 'object' && Object.keys(targetDs).length === 0;
+    const ds = isEmptyDatasourceObject ? panelDatasource : targetDs || panelDatasource;
     const q: PanelQueryKind = {
       kind: 'PanelQuery',
       spec: {
@@ -478,10 +512,12 @@ export function getPanelQueries(targets: DataQuery[], panelDatasource: DataSourc
         query: {
           kind: 'DataQuery',
           version: defaultDataQueryKind().version,
-          group: t.datasource?.type || panelDatasource.type!,
-          datasource: {
-            name: t.datasource?.uid || panelDatasource.uid!,
-          },
+          group: ds.type ?? '',
+          ...(ds.uid && {
+            datasource: {
+              name: ds.uid,
+            },
+          }),
           spec: {
             ...query,
           },
@@ -492,45 +528,145 @@ export function getPanelQueries(targets: DataQuery[], panelDatasource: DataSourc
   });
 }
 
+/**
+ * Known Panel properties from the Panel schema (dashboard_kind.cue).
+ * These should NOT be passed to Angular migration handlers.
+ * Only "unknown" Angular-specific properties should be passed.
+ */
+const knownPanelProperties = new Set([
+  'type',
+  'id',
+  'pluginVersion',
+  'targets',
+  'title',
+  'description',
+  'transparent',
+  'datasource',
+  'gridPos',
+  'links',
+  'repeat',
+  'repeatDirection',
+  'maxPerRow',
+  'maxDataPoints',
+  'transformations',
+  'interval',
+  'timeFrom',
+  'timeShift',
+  'hideTimeOverride',
+  'timeCompare',
+  'libraryPanel',
+  'cacheTimeout',
+  'queryCachingTTL',
+  'options',
+  'fieldConfig',
+  'autoMigrateFrom',
+]);
+
+/**
+ * Extracts only the Angular-specific options from a panel,
+ * filtering out all known Panel schema properties.
+ * This is used to pass just the Angular options to migration handlers
+ * (e.g., sparkline, valueName, format for singlestat).
+ */
+function extractAngularOptions(panel: Panel): Record<string, unknown> {
+  const result: Record<string, unknown> = {};
+  for (const [key, value] of Object.entries(panel)) {
+    if (!knownPanelProperties.has(key)) {
+      result[key] = value;
+    }
+  }
+  return result;
+}
+
 export function buildPanelKind(p: Panel): PanelKind {
-  const queries = getPanelQueries((p.targets as unknown as DataQuery[]) || [], p.datasource || getDefaultDatasource());
+  // eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/consistent-type-assertions
+  const queries = getPanelQueries((p.targets as any) || [], p.datasource ?? { type: '', uid: '' });
 
   const transformations = getPanelTransformations(p.transformations || []);
 
+  const fieldConfig = p.fieldConfig || defaultFieldConfigSource();
+
+  // match backend conversion behavior
+  if (fieldConfig.defaults.mappings && fieldConfig.defaults.mappings.length === 0) {
+    delete fieldConfig.defaults.mappings;
+  }
+  // match backend conversion behavior
+  if (fieldConfig.defaults.custom && Object.keys(fieldConfig.defaults.custom).length === 0) {
+    delete fieldConfig.defaults.custom;
+  }
+
+  // match backend conversion behavior
+  // Only set first threshold step value to null if it's explicitly null or undefined
+  // Preserve 0 values (0 is falsy but should be kept as 0, not converted to null)
+  if (
+    fieldConfig.defaults.thresholds?.steps &&
+    fieldConfig.defaults.thresholds.steps.length > 0 &&
+    (fieldConfig.defaults.thresholds.steps[0]?.value === null ||
+      fieldConfig.defaults.thresholds.steps[0]?.value === undefined)
+  ) {
+    fieldConfig.defaults.thresholds.steps[0]!.value = null;
+  }
+
+  // Build options with Angular migration data if needed (matches backend behavior)
+  // autoMigrateFrom is set during v0->v1 migration when Angular panels are converted
+  let { autoMigrateFrom } = p;
+  let options = p.options ?? {};
+  const originalOptions = extractAngularOptions(p);
+
+  // When autoMigrateFrom is present OR when there are Angular-specific properties at root level,
+  // compose __angularMigration with only Angular-specific options.
+  // This filters out known Panel schema properties, passing only the Angular options to migration handlers.
+  // The second condition handles panels like "text" that have Angular-style properties (content, mode)
+  // but don't have autoMigrateFrom set because they don't need a type conversion.
+  if (!autoMigrateFrom && Object.keys(originalOptions).length > 0) {
+    autoMigrateFrom = p.type;
+  }
+
+  if (autoMigrateFrom) {
+    options = {
+      ...options,
+      __angularMigration: {
+        autoMigrateFrom,
+        originalOptions,
+      },
+    };
+  }
+
   const panelKind: PanelKind = {
     kind: 'Panel',
     spec: {
       title: p.title || '',
       description: p.description || '',
+      ...(p.transparent !== undefined && { transparent: p.transparent }),
       vizConfig: {
         kind: 'VizConfig',
         group: p.type,
-        version: p.pluginVersion!,
+        version: p.pluginVersion ?? '',
         spec: {
-          fieldConfig: (p.fieldConfig as any) || defaultFieldConfigSource(),
-          options: p.options as any,
+          fieldConfig: p.fieldConfig || defaultFieldConfigSource(),
+          options,
         },
       },
       links:
         p.links?.map<DataLink>((l) => ({
           title: l.title,
           url: l.url || '',
-          targetBlank: l.targetBlank,
+          ...(l.targetBlank !== undefined && { targetBlank: l.targetBlank }),
         })) || [],
       id: p.id!,
       data: {
         kind: 'QueryGroup',
         spec: {
-          queries,
+          queries: queries || [defaultPanelQueryKind()],
           transformations,
           queryOptions: {
-            cacheTimeout: p.cacheTimeout,
-            maxDataPoints: p.maxDataPoints,
-            interval: p.interval,
-            hideTimeOverride: p.hideTimeOverride,
-            queryCachingTTL: p.queryCachingTTL,
-            timeFrom: p.timeFrom,
-            timeShift: p.timeShift,
+            ...(p.cacheTimeout !== undefined && { cacheTimeout: p.cacheTimeout }),
+            ...(p.maxDataPoints !== undefined && { maxDataPoints: p.maxDataPoints }),
+            ...(p.interval !== undefined && { interval: p.interval }),
+            ...(p.hideTimeOverride !== undefined && { hideTimeOverride: p.hideTimeOverride }),
+            ...(p.queryCachingTTL !== undefined && { queryCachingTTL: p.queryCachingTTL }),
+            ...(p.timeFrom !== undefined && { timeFrom: p.timeFrom }),
+            ...(p.timeShift !== undefined && { timeShift: p.timeShift }),
           },
         },
       },
@@ -545,7 +681,7 @@ function getPanelTransformations(transformations: DataTransformerConfig[]): Tran
       kind: t.id,
       spec: {
         ...t,
-        topic: transformDataTopic(t.topic),
+        ...(t.topic !== undefined && { topic: transformDataTopic(t.topic) }),
       },
     };
   });
@@ -556,7 +692,7 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
   for (const v of vars) {
     const commonProperties = {
       name: v.name,
-      label: v.label,
+      ...(v.label !== undefined && { label: v.label }),
       ...(v.description && { description: v.description }),
       skipUrlSync: Boolean(v.skipUrlSync),
       hide: transformVariableHideToEnum(v.hide),
@@ -582,25 +718,28 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
           kind: 'QueryVariable',
           spec: {
             ...commonProperties,
-            multi: Boolean(v.multi),
-            includeAll: Boolean(v.includeAll),
+            multi: v.multi ?? false,
+            includeAll: v.includeAll ?? false,
             ...(v.allValue && { allValue: v.allValue }),
             current: {
               value: v.current?.value,
               text: v.current?.text,
             },
-            options: v.options || [],
+            options: v.options ?? [],
+            ...(v.definition && { definition: v.definition }),
             refresh: transformVariableRefreshToEnum(v.refresh),
-            ...(v.datasource && { datasource: v.datasource }),
-            regex: v.regex || '',
-            sort: transformSortVariableToEnum(v.sort),
+            regex: v.regex ?? '',
+            ...(v.regexApplyTo && { regexApplyTo: v.regexApplyTo }),
+            sort: v.sort ? transformSortVariableToEnum(v.sort) : 'disabled',
             query: {
               kind: 'DataQuery',
               version: defaultDataQueryKind().version,
               group: v.datasource?.type ?? getDefaultDatasourceType(),
-              datasource: {
-                name: v.datasource?.uid,
-              },
+              ...(v.datasource?.uid && {
+                datasource: {
+                  name: v.datasource.uid,
+                },
+              }),
               spec: query,
             },
             allowCustomValue: v.allowCustomValue ?? true,
@@ -619,17 +758,17 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
           kind: 'DatasourceVariable',
           spec: {
             ...commonProperties,
-            multi: Boolean(v.multi),
-            includeAll: Boolean(v.includeAll),
+            multi: v.multi ?? false,
+            includeAll: v.includeAll ?? false,
             ...(v.allValue && { allValue: v.allValue }),
             current: {
               value: v.current.value,
               text: v.current.text,
             },
-            options: v.options || [],
+            options: v.options ?? [],
             refresh: transformVariableRefreshToEnum(v.refresh),
             pluginId,
-            regex: v.regex || '',
+            regex: v.regex ?? '',
             allowCustomValue: v.allowCustomValue ?? true,
           },
         };
@@ -645,9 +784,9 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
               value: v.current.value,
               text: v.current.text,
             },
-            options: v.options,
-            multi: v.multi,
-            includeAll: v.includeAll,
+            options: v.options ?? [],
+            multi: v.multi ?? false,
+            includeAll: v.includeAll ?? false,
             ...(v.allValue && { allValue: v.allValue }),
             allowCustomValue: v.allowCustomValue ?? true,
           },
@@ -661,21 +800,23 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
         const av: AdhocVariableKind = {
           kind: 'AdhocVariable',
           group: dsType,
+          ...(ds.uid && {
+            datasource: {
+              name: ds.uid,
+            },
+          }),
           spec: {
             ...commonProperties,
-            baseFilters: validateFiltersOrigin(v.baseFilters) || [],
-            filters: validateFiltersOrigin(v.filters) || [],
-            defaultKeys: v.defaultKeys || [],
+            baseFilters: validateFiltersOrigin(v.baseFilters ?? []),
+            filters: validateFiltersOrigin(v.filters ?? []),
+            defaultKeys:
+              v.defaultKeys?.map((key: string | MetricFindValue) =>
+                typeof key === 'string' ? { text: key, value: key } : key
+              ) ?? [],
             allowCustomValue: v.allowCustomValue ?? true,
           },
         };
 
-        if (ds.uid) {
-          av.datasource = {
-            name: ds.uid,
-          };
-        }
-
         variables.push(av);
         break;
       case 'constant':
@@ -735,6 +876,11 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
         const gb: GroupByVariableKind = {
           kind: 'GroupByVariable',
           group: dsType,
+          ...(ds.uid && {
+            datasource: {
+              name: ds.uid,
+            },
+          }),
           spec: {
             ...commonProperties,
             options: v.options,
@@ -746,14 +892,31 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
           },
         };
 
-        if (ds.uid) {
-          gb.datasource = {
-            name: ds.uid,
-          };
-        }
-
         variables.push(gb);
         break;
+      case 'switch':
+        // V1 switch variables have options array with exactly 2 options
+        // First option is typically enabledValue, second is disabledValue
+        const options = v.options ?? [];
+        const enabledValueRaw = options[0]?.value ?? 'true';
+        const disabledValueRaw = options[1]?.value ?? 'false';
+        const enabledValue = Array.isArray(enabledValueRaw) ? enabledValueRaw[0] : enabledValueRaw;
+        const disabledValue = Array.isArray(disabledValueRaw) ? disabledValueRaw[0] : disabledValueRaw;
+        // Current value should be a string (not array)
+        const currentValueRaw = v.current?.value ?? disabledValue;
+        const currentValue = Array.isArray(currentValueRaw) ? currentValueRaw[0] : currentValueRaw;
+
+        const sw: SwitchVariableKind = {
+          kind: 'SwitchVariable',
+          spec: {
+            ...commonProperties,
+            current: currentValue,
+            enabledValue,
+            disabledValue,
+          },
+        };
+        variables.push(sw);
+        break;
       default:
         // do not throw error, just log it
         console.error(`Variable transformation not implemented: ${v.type}`);
@@ -764,27 +927,35 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
 
 function getAnnotations(annotations: AnnotationQuery[]): DashboardV2Spec['annotations'] {
   return annotations.map((a) => {
+    // Extract properties that are explicitly handled
+    const { name, enable, hide, iconColor, builtIn, datasource, target, filter, mappings, ...legacyOptions } = a;
+
     const aq: AnnotationQueryKind = {
       kind: 'AnnotationQuery',
       spec: {
-        name: a.name,
-        ...(a.datasource && { datasource: a.datasource }),
-        enable: a.enable,
-        hide: Boolean(a.hide),
-        iconColor: a.iconColor,
-        builtIn: Boolean(a.builtIn),
+        name,
+        enable,
+        hide: Boolean(hide),
+        iconColor: iconColor,
+        builtIn: Boolean(builtIn),
+        ...(mappings && { mappings: transformAnnotationMappingsV1ToV2(mappings) }),
         query: {
           kind: 'DataQuery',
           version: defaultDataQueryKind().version,
-          group: a.datasource?.type || getDefaultDatasourceType(),
-          datasource: {
-            name: a.datasource?.uid,
-          },
+          group: datasource?.type || (builtIn ? 'grafana' : ''),
+          ...(datasource?.uid && {
+            datasource: {
+              name: datasource.uid,
+            },
+          }),
           spec: {
-            ...a.target,
+            ...target,
           },
         },
-        filter: a.filter,
+        ...(filter !== undefined && { filter }),
+
+        // Include any additional properties as legacyOptions
+        ...(Object.keys(legacyOptions).length > 0 && { legacyOptions }),
       },
     };
     return aq;
@@ -808,7 +979,10 @@ function getVariablesV1(vars: DashboardV2Spec['variables']): VariableModel[] {
       case 'QueryVariable':
         const qv: VariableModel = {
           ...commonProperties,
-          current: v.spec.current,
+          current: {
+            text: v.spec.current.text,
+            value: v.spec.current.value,
+          },
           options: v.spec.options,
           query:
             LEGACY_STRING_VALUE_KEY in v.spec.query.spec
@@ -821,6 +995,7 @@ function getVariablesV1(vars: DashboardV2Spec['variables']): VariableModel[] {
           sort: transformSortVariableToEnumV1(v.spec.sort),
           refresh: transformVariableRefreshToEnumV1(v.spec.refresh),
           regex: v.spec.regex,
+          regexApplyTo: v.spec.regexApplyTo,
           allValue: v.spec.allValue,
           includeAll: v.spec.includeAll,
           multi: v.spec.multi,
@@ -932,6 +1107,29 @@ function getVariablesV1(vars: DashboardV2Spec['variables']): VariableModel[] {
         };
         variables.push(av);
         break;
+      case 'SwitchVariable':
+        const sv: VariableModel = {
+          ...commonProperties,
+          current: {
+            text: v.spec.current,
+            value: v.spec.current,
+          },
+          options: [
+            {
+              text: v.spec.enabledValue,
+              value: v.spec.enabledValue,
+              selected: v.spec.current === v.spec.enabledValue,
+            },
+            {
+              text: v.spec.disabledValue,
+              value: v.spec.disabledValue,
+              selected: v.spec.current === v.spec.disabledValue,
+            },
+          ],
+          query: '',
+        };
+        variables.push(sv);
+        break;
       default:
         // do not throw error, just log it
         console.error(`Variable transformation not implemented: ${v}`);
@@ -994,7 +1192,7 @@ function transformV2PanelToV1Panel(
         panel.links?.map<DashboardLink>((l) => ({
           title: l.title,
           url: l.url,
-          ...(l.targetBlank && { targetBlank: l.targetBlank }),
+          ...(l.targetBlank !== undefined && { targetBlank: l.targetBlank }),
         })) || [],
       targets: panel.data.spec.queries.map((q) => {
         return {
@@ -1009,17 +1207,27 @@ function transformV2PanelToV1Panel(
       }),
       transformations: panel.data.spec.transformations.map((t) => t.spec),
       gridPos,
-      cacheTimeout: panel.data.spec.queryOptions.cacheTimeout,
-      maxDataPoints: panel.data.spec.queryOptions.maxDataPoints,
-      interval: panel.data.spec.queryOptions.interval,
-      hideTimeOverride: panel.data.spec.queryOptions.hideTimeOverride,
-      queryCachingTTL: panel.data.spec.queryOptions.queryCachingTTL,
-      timeFrom: panel.data.spec.queryOptions.timeFrom,
-      timeShift: panel.data.spec.queryOptions.timeShift,
-      transparent: panel.transparent,
-      ...(repeat?.value && { repeat: repeat.value }),
-      ...(repeat?.direction && { repeatDirection: repeat.direction }),
-      ...(repeat?.maxPerRow && { maxPerRow: repeat.maxPerRow }),
+      ...(panel.data.spec.queryOptions.cacheTimeout !== undefined && {
+        cacheTimeout: panel.data.spec.queryOptions.cacheTimeout,
+      }),
+      ...(panel.data.spec.queryOptions.maxDataPoints !== undefined && {
+        maxDataPoints: panel.data.spec.queryOptions.maxDataPoints,
+      }),
+      ...(panel.data.spec.queryOptions.interval !== undefined && { interval: panel.data.spec.queryOptions.interval }),
+      ...(panel.data.spec.queryOptions.hideTimeOverride !== undefined && {
+        hideTimeOverride: panel.data.spec.queryOptions.hideTimeOverride,
+      }),
+      ...(panel.data.spec.queryOptions.queryCachingTTL !== undefined && {
+        queryCachingTTL: panel.data.spec.queryOptions.queryCachingTTL,
+      }),
+      ...(panel.data.spec.queryOptions.timeFrom !== undefined && { timeFrom: panel.data.spec.queryOptions.timeFrom }),
+      ...(panel.data.spec.queryOptions.timeShift !== undefined && {
+        timeShift: panel.data.spec.queryOptions.timeShift,
+      }),
+      ...(panel.transparent !== undefined && { transparent: panel.transparent }),
+      ...(repeat?.value !== undefined && { repeat: repeat.value }),
+      ...(repeat?.direction !== undefined && { repeatDirection: repeat.direction }),
+      ...(repeat?.maxPerRow !== undefined && { maxPerRow: repeat.maxPerRow }),
     };
   } else if (p.kind === 'LibraryPanel') {
     const panel = p.spec;
@@ -1054,7 +1262,7 @@ export function transformMappingsToV1(fieldConfig: FieldConfigSource): FieldConf
     ...fieldConfig.defaults,
   };
 
-  if (fieldConfig.defaults.mappings) {
+  if (fieldConfig.defaults.mappings && fieldConfig.defaults.mappings.length > 0) {
     transformedDefaults.mappings = fieldConfig.defaults.mappings.map((mapping) => {
       switch (mapping.type) {
         case 'value':
@@ -1135,6 +1343,16 @@ function colorIdToEnumv1(colorId: FieldColorModeId): FieldColorModeIdV1 {
       return FieldColorModeIdV1.ContinuousGreens;
     case 'continuous-purples':
       return FieldColorModeIdV1.ContinuousPurples;
+    case 'continuous-viridis':
+      return FieldColorModeIdV1.ContinuousViridis;
+    case 'continuous-magma':
+      return FieldColorModeIdV1.ContinuousMagma;
+    case 'continuous-plasma':
+      return FieldColorModeIdV1.ContinuousPlasma;
+    case 'continuous-inferno':
+      return FieldColorModeIdV1.ContinuousInferno;
+    case 'continuous-cividis':
+      return FieldColorModeIdV1.ContinuousCividis;
     case 'fixed':
       return FieldColorModeIdV1.Fixed;
     case 'shades':
@@ -1181,6 +1399,8 @@ function transformToV1VariableTypes(variable: TypedVariableModelV2): VariableTyp
       return 'groupby';
     case 'AdhocVariable':
       return 'adhoc';
+    case 'SwitchVariable':
+      return 'switch';
     default:
       throw new Error(`Unknown variable type: ${variable}`);
   }
@@ -1224,3 +1444,25 @@ export function transformDashboardV2SpecToV1(spec: DashboardV2Spec, metadata: Ob
     templating: { list: variables },
   };
 }
+
+export function transformAnnotationMappingsV1ToV2(
+  mappings: AnnotationQuery['mappings']
+): AnnotationQueryKind['spec']['mappings'] {
+  if (!mappings) {
+    return {};
+  }
+
+  return Object.fromEntries(
+    Object.entries(mappings).map(([key, value]) => {
+      if (typeof value === 'string') {
+        return [key, { source: 'field', value }];
+      }
+
+      if (typeof value === 'object') {
+        return [key, value.source ? value : { source: 'field', ...value }];
+      }
+
+      return [key, value];
+    })
+  );
+}
