@@ -1,9 +1,11 @@
 // Libraries
-import React, { FunctionComponent, MouseEvent } from 'react';
 import { css } from '@emotion/css';
+import { MouseEvent } from 'react';
+import * as React from 'react';
+
 // Components
-import { IconName, IconType, IconSize, IconButton, useTheme, stylesFactory } from '@grafana/ui';
-import { GrafanaTheme } from '@grafana/data';
+import { GrafanaTheme2 } from '@grafana/data';
+import { IconName, IconType, IconSize, IconButton, useStyles2 } from '@grafana/ui';
 
 interface Props {
   icon?: IconName;
@@ -15,9 +17,8 @@ interface Props {
   iconSize?: IconSize;
 }
 
-export const DashNavButton: FunctionComponent<Props> = ({ icon, iconType, iconSize, tooltip, onClick, children }) => {
-  const theme = useTheme();
-  const styles = getStyles(theme);
+export const DashNavButton = ({ icon, iconType, iconSize, tooltip, onClick, children }: Props) => {
+  const styles = useStyles2(getStyles);
 
   return (
     <div className={styles.noBorderContainer}>
@@ -36,9 +37,9 @@ export const DashNavButton: FunctionComponent<Props> = ({ icon, iconType, iconSi
   );
 };
 
-const getStyles = stylesFactory((theme: GrafanaTheme) => ({
-  noBorderContainer: css`
-    padding: 0 ${theme.spacing.xs};
-    display: flex;
-  `,
-}));
+const getStyles = (theme: GrafanaTheme2) => ({
+  noBorderContainer: css({
+    padding: `0 ${theme.spacing(0.5)}`,
+    display: 'flex',
+  }),
+});
