@@ -1,4 +1,4 @@
-import { render, screen } from '@testing-library/react';
+import { render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
 
 import { BootData, getDefaultTimeRange } from '@grafana/data';
@@ -7,10 +7,11 @@ import { setEchoSrv, setTemplateSrv } from '@grafana/runtime';
 import config from 'app/core/config';
 
 import { initTemplateSrv } from '../../../../../test/helpers/initTemplateSrv';
+import { contextSrv } from '../../../../core/services/context_srv';
 import { Echo } from '../../../../core/services/echo/Echo';
 import { variableAdapters } from '../../../variables/adapters';
 import { createQueryVariableAdapter } from '../../../variables/query/adapter';
-import { PanelModel } from '../../state';
+import { PanelModel } from '../../state/PanelModel';
 import { createDashboardModelFixture } from '../../state/__fixtures__/dashboardFixtures';
 
 import { Props, ShareLink } from './ShareLink';
@@ -32,9 +33,10 @@ function mockLocationHref(href: string) {
     search = href.substring(searchPos);
   }
 
+  const win: typeof globalThis = window;
   //@ts-ignore
-  delete window.location;
-  window.location = {
+  delete win.location;
+  win.location = {
     ...location,
     href,
     origin: new URL(href).origin,
@@ -78,7 +80,7 @@ describe('ShareModal', () => {
     });
     mockLocationHref('http://server/#!/test');
     config.rendererAvailable = true;
-    config.bootData.user.orgId = 1;
+    contextSrv.user.orgId = 1;
     props = {
       panel: new PanelModel({ id: 22, options: {}, fieldConfig: { defaults: {}, overrides: [] } }),
       dashboard: createDashboardModelFixture({
@@ -94,9 +96,11 @@ describe('ShareModal', () => {
   describe('with current time range and panel', () => {
     it('should generate share url absolute time', async () => {
       render(<ShareLink {...props} />);
-      expect(await screen.findByRole('textbox', { name: 'Link URL' })).toHaveValue(
-        'http://server/#!/test?from=1000&to=2000&orgId=1&viewPanel=22'
-      );
+      const linkUrl = await screen.findByRole('textbox', { name: 'Link URL' });
+
+      await waitFor(() => {
+        expect(linkUrl).toHaveValue('http://server/#!/test?from=1000&to=2000&orgId=1&viewPanel=22');
+      });
     });
 
     it('should generate render url', async () => {
@@ -104,10 +108,11 @@ describe('ShareModal', () => {
       render(<ShareLink {...props} />);
 
       const base = 'http://dashboards.grafana.com/render/d-solo/abcdefghi/my-dash';
-      const params = '?from=1000&to=2000&orgId=1&panelId=22&width=1000&height=500&scale=1&tz=UTC';
-      expect(
-        await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage })
-      ).toHaveAttribute('href', base + params);
+      const params = '?from=1000&to=2000&orgId=1&panelId=22&hideLogo=true&width=1000&height=500&scale=1&tz=UTC';
+      const linkUrl = await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage });
+      await waitFor(() => {
+        expect(linkUrl).toHaveAttribute('href', base + params);
+      });
     });
 
     it('should generate render url for scripted dashboard', async () => {
@@ -115,18 +120,20 @@ describe('ShareModal', () => {
       render(<ShareLink {...props} />);
 
       const base = 'http://dashboards.grafana.com/render/dashboard-solo/script/my-dash.js';
-      const params = '?from=1000&to=2000&orgId=1&panelId=22&width=1000&height=500&scale=1&tz=UTC';
-      expect(
-        await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage })
-      ).toHaveAttribute('href', base + params);
+      const params = '?from=1000&to=2000&orgId=1&panelId=22&hideLogo=true&width=1000&height=500&scale=1&tz=UTC';
+      const linkUrl = await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage });
+      await waitFor(() => {
+        expect(linkUrl).toHaveAttribute('href', base + params);
+      });
     });
 
     it('should remove panel id when no panel in scope', async () => {
       props.panel = undefined;
       render(<ShareLink {...props} />);
-      expect(await screen.findByRole('textbox', { name: 'Link URL' })).toHaveValue(
-        'http://server/#!/test?from=1000&to=2000&orgId=1'
-      );
+      const linkUrl = await screen.findByRole('textbox', { name: 'Link URL' });
+      await waitFor(() => {
+        expect(linkUrl).toHaveValue('http://server/#!/test?from=1000&to=2000&orgId=1');
+      });
     });
 
     it('should add theme when specified', async () => {
@@ -134,9 +141,10 @@ describe('ShareModal', () => {
       render(<ShareLink {...props} />);
 
       await userEvent.click(screen.getByLabelText('Light'));
-      expect(await screen.findByRole('textbox', { name: 'Link URL' })).toHaveValue(
-        'http://server/#!/test?from=1000&to=2000&orgId=1&theme=light'
-      );
+      const linkUrl = await screen.findByRole('textbox', { name: 'Link URL' });
+      await waitFor(() => {
+        expect(linkUrl).toHaveValue('http://server/#!/test?from=1000&to=2000&orgId=1&theme=light');
+      });
     });
 
     it('should remove editPanel from image url when is first param in querystring', async () => {
@@ -145,24 +153,28 @@ describe('ShareModal', () => {
 
       const base = 'http://server';
       const path = '/#!/test';
-      expect(await screen.findByRole('textbox', { name: 'Link URL' })).toHaveValue(
-        base + path + '?editPanel=1&from=1000&to=2000&orgId=1'
-      );
-      expect(
-        await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage })
-      ).toHaveAttribute(
-        'href',
-        base + path + '?from=1000&to=2000&orgId=1&panelId=1&width=1000&height=500&scale=1&tz=UTC'
-      );
+      const textboxUrl = await screen.findByRole('textbox', { name: 'Link URL' });
+      const linkUrl = await screen.findByRole('link', {
+        name: selectors.pages.SharePanelModal.linkToRenderedImage,
+      });
+      await waitFor(() => {
+        expect(textboxUrl).toHaveValue(base + path + '?editPanel=1&from=1000&to=2000&orgId=1');
+        expect(linkUrl).toHaveAttribute(
+          'href',
+          base + path + '?from=1000&to=2000&orgId=1&panelId=1&hideLogo=true&width=1000&height=500&scale=1&tz=UTC'
+        );
+      });
     });
 
     it('should shorten url', async () => {
       render(<ShareLink {...props} />);
 
       await userEvent.click(await screen.findByLabelText('Shorten URL'));
-      expect(await screen.findByRole('textbox', { name: 'Link URL' })).toHaveValue(
-        `http://localhost:3000/goto/${mockUid}`
-      );
+      const linkUrl = await screen.findByRole('textbox', { name: 'Link URL' });
+
+      await waitFor(() => {
+        expect(linkUrl).toHaveValue(`http://localhost:3000/goto/${mockUid}`);
+      });
     });
 
     it('should generate render url without shareView param', async () => {
@@ -170,10 +182,11 @@ describe('ShareModal', () => {
       render(<ShareLink {...props} />);
 
       const base = 'http://dashboards.grafana.com/render/d-solo/abcdefghi/my-dash';
-      const params = '?from=1000&to=2000&orgId=1&panelId=22&width=1000&height=500&scale=1&tz=UTC';
-      expect(
-        await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage })
-      ).toHaveAttribute('href', base + params);
+      const params = '?from=1000&to=2000&orgId=1&panelId=22&hideLogo=true&width=1000&height=500&scale=1&tz=UTC';
+      const linkUrl = await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage });
+      await waitFor(() => {
+        expect(linkUrl).toHaveAttribute('href', base + params);
+      });
     });
   });
 });
@@ -185,7 +198,7 @@ describe('when appUrl is set in the grafana config', () => {
     originalBootData = config.bootData;
     config.appUrl = 'http://dashboards.grafana.com/';
     config.rendererAvailable = true;
-    config.bootData.user.orgId = 1;
+    contextSrv.user.orgId = 1;
   });
 
   afterAll(() => {
@@ -207,11 +220,12 @@ describe('when appUrl is set in the grafana config', () => {
     mockLocationHref('http://dashboards.grafana.com/?orgId=1');
     render(<ShareLink {...props} />);
 
-    expect(
-      await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage })
-    ).toHaveAttribute(
-      'href',
-      `http://dashboards.grafana.com/render/d-solo/${mockDashboard.uid}?orgId=1&from=1000&to=2000&panelId=${mockPanel.id}&width=1000&height=500&scale=1&tz=UTC`
-    );
+    const linkUrl = await screen.findByRole('link', { name: selectors.pages.SharePanelModal.linkToRenderedImage });
+    await waitFor(() => {
+      expect(linkUrl).toHaveAttribute(
+        'href',
+        `http://dashboards.grafana.com/render/d-solo/${mockDashboard.uid}?orgId=1&from=1000&to=2000&panelId=${mockPanel.id}&hideLogo=true&width=1000&height=500&scale=1&tz=UTC`
+      );
+    });
   });
 });
