@@ -5,8 +5,8 @@ import { useEffectOnce } from 'react-use';
 import { Props as AutoSizerProps } from 'react-virtualized-auto-sizer';
 import { render } from 'test/test-utils';
 
-import { selectors as e2eSelectors } from '@grafana/e2e-selectors/src';
-import { Dashboard, DashboardCursorSync, FieldConfigSource, Panel, ThresholdsMode } from '@grafana/schema/src';
+import { selectors as e2eSelectors } from '@grafana/e2e-selectors';
+import { Dashboard, DashboardCursorSync, FieldConfigSource, Panel, ThresholdsMode } from '@grafana/schema';
 import { getRouteComponentProps } from 'app/core/navigation/mocks/routeProps';
 import { DashboardInitPhase, DashboardMeta, DashboardRoutes } from 'app/types/dashboard';
 import { StoreState } from 'app/types/store';
@@ -202,6 +202,7 @@ describe('PublicDashboardPage', () => {
           repeatDirection: 'h',
           transformations: [],
           transparent: false,
+          description: 'hello',
         },
       ];
 
