@@ -1,5 +1,5 @@
 import { getBackendSrv } from '@grafana/runtime';
-import { contextSrv } from 'app/core/core';
+import { contextSrv } from 'app/core/services/context_srv';
 import { FormModel } from 'app/features/org/UserInviteForm';
 import { AccessControlAction } from 'app/types/accessControl';
 import { createAsyncThunk } from 'app/types/store';
