@@ -1,10 +1,13 @@
 import { useState } from 'react';
 
 import { SelectableValue, UrlQueryMap, urlUtil } from '@grafana/data';
-import { config, locationService } from '@grafana/runtime';
+import { Trans, t } from '@grafana/i18n';
+import { config, locationService, reportInteraction } from '@grafana/runtime';
 import { Box, Button, Checkbox, Field, FieldSet, Modal, RadioButtonGroup, Stack } from '@grafana/ui';
 
-import { Playlist, PlaylistMode } from './types';
+import { Playlist } from '../../api/clients/playlist/v1';
+
+import { PlaylistMode } from './types';
 
 export interface Props {
   playlist: Playlist;
@@ -19,9 +22,8 @@ export const StartModal = ({ playlist, onDismiss }: Props) => {
   const [displayLinks, setDisplayLinks] = useState(true);
 
   const modes: Array<SelectableValue<PlaylistMode>> = [
-    { label: 'Normal', value: false },
-    { label: 'TV', value: 'tv' },
-    { label: 'Kiosk', value: true },
+    { label: t('playlist.start-modal.modes.label.normal', 'Normal'), value: false },
+    { label: t('playlist.start-modal.modes.label.kiosk', 'Kiosk'), value: true },
   ];
 
   const onStart = () => {
@@ -43,42 +45,60 @@ export const StartModal = ({ playlist, onDismiss }: Props) => {
       params['_dash.hideLinks'] = true;
     }
 
-    locationService.push(urlUtil.renderUrl(`/playlists/play/${playlist.uid}`, params));
+    locationService.push(urlUtil.renderUrl(`/playlists/play/${playlist.metadata?.name}`, params));
+    reportInteraction('grafana_kiosk_mode', {
+      action: 'start_playlist',
+      mode: mode,
+    });
   };
 
   return (
-    <Modal isOpen={true} icon="play" title="Start playlist" onDismiss={onDismiss}>
+    <Modal
+      isOpen={true}
+      icon="play"
+      title={t('playlist.start-modal.title-start-playlist', 'Start playlist')}
+      onDismiss={onDismiss}
+    >
       <FieldSet>
-        <Field label="Mode">
+        <Field label={t('playlist.start-modal.label-mode', 'Mode')}>
           <RadioButtonGroup value={mode} options={modes} onChange={setMode} />
         </Field>
         <Field>
           <Checkbox
-            label="Autofit"
-            description="Panel heights will be adjusted to fit screen size"
+            label={t('playlist.start-modal.label-autofit', 'Autofit')}
+            description={t(
+              'playlist.start-modal.description-panel-heights-adjusted-screen',
+              'Panel heights will be adjusted to fit screen size'
+            )}
             name="autofix"
             value={autoFit}
             onChange={(e) => setAutofit(e.currentTarget.checked)}
           />
         </Field>
         {config.featureToggles.dashboardScene && (
-          <Field label="Display dashboard controls" description="Customize dashboard elements visibility">
+          <Field
+            label={t('playlist.start-modal.label-display-dashboard-controls', 'Display dashboard controls')}
+            description={t(
+              'playlist.start-modal.description-customize-dashboard-elements-visibility',
+              'Customize dashboard elements visibility'
+            )}
+          >
             <Box marginTop={2} marginBottom={2}>
               <Stack direction="column" alignItems="start" justifyContent="left" gap={2}>
                 <Checkbox
-                  label="Time and refresh"
+                  label={t('playlist.start-modal.label-time-and-refresh', 'Time and refresh')}
                   name="displayTimePicker"
                   value={displayTimePicker}
                   onChange={(e) => setDisplayTimePicker(e.currentTarget.checked)}
                 />
                 <Checkbox
-                  label="Variables"
+                  label={t('playlist.start-modal.label-variables', 'Variables')}
                   name="displayVariableControls"
                   value={displayVariables}
                   onChange={(e) => setDisplayVariables(e.currentTarget.checked)}
                 />
                 <Checkbox
-                  label="Dashboard links"
+                  label={t('playlist.start-modal.label-dashboard-links', 'Dashboard links')}
                   name="displayLinks"
                   value={displayLinks}
                   onChange={(e) => setDisplayLinks(e.currentTarget.checked)}
@@ -90,7 +110,9 @@ export const StartModal = ({ playlist, onDismiss }: Props) => {
       </FieldSet>
       <Modal.ButtonRow>
         <Button variant="primary" onClick={onStart}>
-          Start {playlist.name}
+          <Trans i18nKey="playlist.start-modal.button-start" values={{ title: playlist.spec?.title }}>
+            Start {'{{title}}'}
+          </Trans>
         </Button>
       </Modal.ButtonRow>
     </Modal>
