@@ -1,11 +1,11 @@
 import React from 'react';
-import { firstValueFrom } from 'rxjs';
+import { firstValueFrom, take } from 'rxjs';
 
-import { PluginLoadingStrategy } from '@grafana/data';
-import { config } from '@grafana/runtime';
+import { AppPluginConfig } from '@grafana/data';
 
 import { log } from '../logs/log';
 import { resetLogMock } from '../logs/testUtils';
+import { basicApp } from '../test-fixtures/config.apps';
 import { isGrafanaDevMode } from '../utils';
 
 import { AddedComponentsRegistry } from './AddedComponentsRegistry';
@@ -30,48 +30,17 @@ jest.mock('../logs/log', () => {
 });
 
 describe('AddedComponentsRegistry', () => {
-  const originalApps = config.apps;
-  const pluginId = 'grafana-basic-app';
-  const appPluginConfig = {
-    id: pluginId,
-    path: '',
-    version: '',
-    preload: false,
-    angular: {
-      detected: false,
-      hideDeprecation: false,
-    },
-    loadingStrategy: PluginLoadingStrategy.fetch,
-    dependencies: {
-      grafanaVersion: '8.0.0',
-      plugins: [],
-      extensions: {
-        exposedComponents: [],
-      },
-    },
-    extensions: {
-      addedLinks: [],
-      addedComponents: [],
-      addedFunctions: [],
-      exposedComponents: [],
-      extensionPoints: [],
-    },
-  };
+  const pluginId = basicApp.id;
+  const apps = [basicApp];
+  const createRegistry = async (override: AppPluginConfig[] = apps) => new AddedComponentsRegistry(override);
 
   beforeEach(() => {
     resetLogMock(log);
     jest.mocked(isGrafanaDevMode).mockReturnValue(false);
-    config.apps = {
-      [pluginId]: appPluginConfig,
-    };
-  });
-
-  afterEach(() => {
-    config.apps = originalApps;
   });
 
   it('should return empty registry when no extensions registered', async () => {
-    const reactiveRegistry = new AddedComponentsRegistry();
+    const reactiveRegistry = await createRegistry();
     const observable = reactiveRegistry.asObservable();
     const registry = await firstValueFrom(observable);
     expect(registry).toEqual({});
@@ -79,7 +48,7 @@ describe('AddedComponentsRegistry', () => {
 
   it('should be possible to register added components in the registry', async () => {
     const extensionPointId = `${pluginId}/hello-world/v1`;
-    const reactiveRegistry = new AddedComponentsRegistry();
+    const reactiveRegistry = await createRegistry();
 
     reactiveRegistry.register({
       pluginId,
@@ -107,7 +76,7 @@ describe('AddedComponentsRegistry', () => {
     const pluginId1 = 'grafana-basic-app';
     const pluginId2 = 'grafana-basic-app2';
     const extensionPointId = 'grafana/alerting/home';
-    const reactiveRegistry = new AddedComponentsRegistry();
+    const reactiveRegistry = await createRegistry();
 
     // Register extensions for the first plugin
     reactiveRegistry.register({
@@ -166,7 +135,7 @@ describe('AddedComponentsRegistry', () => {
     const pluginId2 = 'grafana-basic-app2';
     const extensionPointId1 = 'grafana/alerting/home';
     const extensionPointId2 = 'grafana/user/profile/tab';
-    const reactiveRegistry = new AddedComponentsRegistry();
+    const reactiveRegistry = await createRegistry();
 
     // Register extensions for the first plugin
     reactiveRegistry.register({
@@ -226,7 +195,7 @@ describe('AddedComponentsRegistry', () => {
   });
 
   it('should be possible to asynchronously register component extensions for the same extension point (same plugin)', async () => {
-    const reactiveRegistry = new AddedComponentsRegistry();
+    const reactiveRegistry = await createRegistry();
     const extensionPointId = 'grafana/alerting/home';
 
     // Register extensions for the first extension point
@@ -265,7 +234,7 @@ describe('AddedComponentsRegistry', () => {
   });
 
   it('should be possible to register one extension component targeting multiple extension points', async () => {
-    const reactiveRegistry = new AddedComponentsRegistry();
+    const reactiveRegistry = await createRegistry();
     const extensionPointId1 = 'grafana/alerting/home';
     const extensionPointId2 = 'grafana/user/profile/tab';
 
@@ -304,7 +273,7 @@ describe('AddedComponentsRegistry', () => {
     const pluginId2 = 'myorg-extensions-app';
     const extensionPointId1 = 'grafana/alerting/home';
     const extensionPointId2 = 'grafana/user/profile/tab';
-    const reactiveRegistry = new AddedComponentsRegistry();
+    const reactiveRegistry = await createRegistry();
     const observable = reactiveRegistry.asObservable();
     const subscribeCallback = jest.fn();
 
@@ -359,7 +328,7 @@ describe('AddedComponentsRegistry', () => {
   });
 
   it('should not register component when title is missing', async () => {
-    const registry = new AddedComponentsRegistry();
+    const registry = await createRegistry();
     const extensionPointId = 'grafana/alerting/home';
 
     registry.register({
@@ -381,7 +350,7 @@ describe('AddedComponentsRegistry', () => {
   });
 
   it('should not be possible to register a component on a read-only registry', async () => {
-    const registry = new AddedComponentsRegistry();
+    const registry = await createRegistry();
     const readOnlyRegistry = registry.readOnly();
     const extensionPointId = 'grafana/alerting/home';
 
@@ -405,7 +374,7 @@ describe('AddedComponentsRegistry', () => {
 
   it('should pass down fresh registrations to the read-only version of the registry', async () => {
     const pluginId = 'grafana-basic-app';
-    const registry = new AddedComponentsRegistry();
+    const registry = await createRegistry();
     const readOnlyRegistry = registry.readOnly();
     const subscribeCallback = jest.fn();
     let readOnlyState;
@@ -441,7 +410,7 @@ describe('AddedComponentsRegistry', () => {
     // Enabling dev mode
     jest.mocked(isGrafanaDevMode).mockReturnValue(true);
 
-    const registry = new AddedComponentsRegistry();
+    const registry = await createRegistry();
     const componentConfig = {
       title: 'Component title',
       description: 'Component description',
@@ -449,9 +418,6 @@ describe('AddedComponentsRegistry', () => {
       component: () => React.createElement('div', null, 'Hello World1'),
     };
 
-    // Make sure that the meta-info is empty
-    config.apps[pluginId].extensions.addedComponents = [];
-
     registry.register({
       pluginId,
       configs: [componentConfig],
@@ -467,7 +433,7 @@ describe('AddedComponentsRegistry', () => {
     // Enabling dev mode
     jest.mocked(isGrafanaDevMode).mockReturnValue(true);
 
-    const registry = new AddedComponentsRegistry();
+    const registry = await createRegistry();
     const componentConfig = {
       title: 'Component title',
       description: 'Component description',
@@ -490,7 +456,7 @@ describe('AddedComponentsRegistry', () => {
     // Production mode
     jest.mocked(isGrafanaDevMode).mockReturnValue(false);
 
-    const registry = new AddedComponentsRegistry();
+    const registry = await createRegistry();
     const componentConfig = {
       title: 'Component title',
       description: 'Component description',
@@ -498,9 +464,6 @@ describe('AddedComponentsRegistry', () => {
       component: () => React.createElement('div', null, 'Hello World1'),
     };
 
-    // Make sure that the meta-info is empty
-    config.apps[pluginId].extensions.addedComponents = [];
-
     registry.register({
       pluginId,
       configs: [componentConfig],
@@ -516,16 +479,18 @@ describe('AddedComponentsRegistry', () => {
     // Enabling dev mode
     jest.mocked(isGrafanaDevMode).mockReturnValue(true);
 
-    const registry = new AddedComponentsRegistry();
     const componentConfig = {
       title: 'Component title',
       description: 'Component description',
       targets: ['grafana/alerting/home'],
       component: () => React.createElement('div', null, 'Hello World1'),
     };
-
-    // Make sure that the meta-info is empty
-    config.apps[pluginId].extensions.addedComponents = [componentConfig];
+    const { description, targets, title } = componentConfig;
+    const app = {
+      ...basicApp,
+      extensions: { ...basicApp.extensions, addedComponents: [{ description, targets, title }] },
+    };
+    const registry = await createRegistry([app]);
 
     registry.register({
       pluginId,
@@ -537,4 +502,238 @@ describe('AddedComponentsRegistry', () => {
     expect(Object.keys(currentState)).toHaveLength(1);
     expect(log.warning).not.toHaveBeenCalled();
   });
+
+  describe('asObservableSlice', () => {
+    it('should return the selected slice from the registry', async () => {
+      const registry = await createRegistry();
+      const extensionPointId = 'grafana/alerting/home';
+
+      registry.register({
+        pluginId: 'test-plugin',
+        configs: [
+          {
+            title: 'Test Component',
+            description: 'Test description',
+            targets: [extensionPointId],
+            component: () => React.createElement('div', null, 'Test'),
+          },
+        ],
+      });
+
+      const observable = registry.asObservableSlice((state) => state[extensionPointId]).pipe(take(1));
+
+      await expect(observable).toEmitValuesWith((received) => {
+        const [slice] = received;
+
+        expect(slice).toBeDefined();
+        expect(Array.isArray(slice)).toBe(true);
+        expect(slice?.length).toBe(1);
+        expect(slice?.[0].title).toBe('Test Component');
+      });
+    });
+
+    it('should return undefined when the selected key does not exist', async () => {
+      const registry = await createRegistry();
+      const observable = registry.asObservableSlice((state) => state['non-existent-key']).pipe(take(1));
+
+      await expect(observable).toEmitValuesWith((received) => {
+        const [slice] = received;
+        expect(slice).toBeUndefined();
+      });
+    });
+
+    it('should only emit when the selected slice changes', async () => {
+      const registry = await createRegistry();
+      const extensionPointId = 'grafana/alerting/home';
+      const subscribeCallback = jest.fn();
+
+      const observable = registry.asObservableSlice((state) => state[extensionPointId]);
+      observable.subscribe(subscribeCallback);
+
+      // Initial empty state
+      expect(subscribeCallback).toHaveBeenCalledTimes(1);
+      expect(subscribeCallback.mock.calls[0][0]).toBeUndefined();
+
+      // Register first component
+      registry.register({
+        pluginId: 'test-plugin-1',
+        configs: [
+          {
+            title: 'Component 1',
+            description: 'Description 1',
+            targets: [extensionPointId],
+            component: () => React.createElement('div', null, 'Component 1'),
+          },
+        ],
+      });
+
+      // Should emit because the slice changed
+      expect(subscribeCallback).toHaveBeenCalledTimes(2);
+      expect(subscribeCallback.mock.calls[1][0]?.length).toBe(1);
+
+      // Register another component to the same extension point
+      registry.register({
+        pluginId: 'test-plugin-2',
+        configs: [
+          {
+            title: 'Component 2',
+            description: 'Description 2',
+            targets: [extensionPointId],
+            component: () => React.createElement('div', null, 'Component 2'),
+          },
+        ],
+      });
+
+      // Should emit because the slice changed (array reference changed)
+      expect(subscribeCallback).toHaveBeenCalledTimes(3);
+      expect(subscribeCallback.mock.calls[2][0]?.length).toBe(2);
+
+      // Register a component to a different extension point
+      registry.register({
+        pluginId: 'test-plugin-3',
+        configs: [
+          {
+            title: 'Component 3',
+            description: 'Description 3',
+            targets: ['grafana/other/point'],
+            component: () => React.createElement('div', null, 'Component 3'),
+          },
+        ],
+      });
+
+      // Should NOT emit because the selected slice (for extensionPointId) didn't change
+      expect(subscribeCallback).toHaveBeenCalledTimes(3);
+    });
+
+    it('should deep freeze the selected slice', async () => {
+      const registry = await createRegistry();
+      const extensionPointId = 'grafana/alerting/home';
+
+      registry.register({
+        pluginId: 'test-plugin',
+        configs: [
+          {
+            title: 'Test Component',
+            description: 'Test description',
+            targets: [extensionPointId],
+            component: () => React.createElement('div', null, 'Test'),
+          },
+        ],
+      });
+
+      const observable = registry.asObservableSlice((state) => state[extensionPointId]).pipe(take(1));
+
+      await expect(observable).toEmitValuesWith((received) => {
+        const [slice] = received;
+
+        expect(slice).toBeDefined();
+        // @ts-expect-error - Testing that frozen objects cannot be modified
+        expect(() => slice.push({})).toThrow();
+        expect(() => (slice[0].title = 'Modified')).toThrow();
+      });
+    });
+
+    it('should work with read-only registries', async () => {
+      const registry = await createRegistry();
+      const readOnlyRegistry = registry.readOnly();
+      const extensionPointId = 'grafana/alerting/home';
+
+      registry.register({
+        pluginId: 'test-plugin',
+        configs: [
+          {
+            title: 'Test Component',
+            description: 'Test description',
+            targets: [extensionPointId],
+            component: () => React.createElement('div', null, 'Test'),
+          },
+        ],
+      });
+
+      const observable = readOnlyRegistry.asObservableSlice((state) => state[extensionPointId]).pipe(take(1));
+
+      await expect(observable).toEmitValuesWith((received) => {
+        const [slice] = received;
+
+        expect(slice).toBeDefined();
+        expect(Array.isArray(slice)).toBe(true);
+        expect(slice?.length).toBe(1);
+        expect(slice?.[0].title).toBe('Test Component');
+      });
+    });
+
+    it('should emit immediately to new subscribers with the current slice value', async () => {
+      const registry = await createRegistry();
+      const extensionPointId = 'grafana/alerting/home';
+
+      registry.register({
+        pluginId: 'test-plugin',
+        configs: [
+          {
+            title: 'Test Component',
+            description: 'Test description',
+            targets: [extensionPointId],
+            component: () => React.createElement('div', null, 'Test'),
+          },
+        ],
+      });
+
+      // Subscribe after registration
+      const observable = registry.asObservableSlice((state) => state[extensionPointId]);
+      const subscribeCallback = jest.fn();
+      observable.subscribe(subscribeCallback);
+
+      // Should have been called immediately with the current value
+      expect(subscribeCallback).toHaveBeenCalledTimes(1);
+      expect(subscribeCallback.mock.calls[0][0]?.length).toBe(1);
+      expect(subscribeCallback.mock.calls[0][0]?.[0].title).toBe('Test Component');
+    });
+
+    it('should not emit when Object.is returns true for the same value', async () => {
+      const registry = await createRegistry();
+      const extensionPointId = 'grafana/alerting/home';
+      const subscribeCallback = jest.fn();
+
+      const observable = registry.asObservableSlice((state) => state[extensionPointId]);
+      observable.subscribe(subscribeCallback);
+
+      // Initial state
+      expect(subscribeCallback).toHaveBeenCalledTimes(1);
+
+      // Register a component
+      registry.register({
+        pluginId: 'test-plugin',
+        configs: [
+          {
+            title: 'Test Component',
+            description: 'Test description',
+            targets: [extensionPointId],
+            component: () => React.createElement('div', null, 'Test'),
+          },
+        ],
+      });
+
+      // Should emit once more
+      expect(subscribeCallback).toHaveBeenCalledTimes(2);
+      const firstValue = subscribeCallback.mock.calls[1][0];
+
+      // Register another component to a different extension point
+      registry.register({
+        pluginId: 'test-plugin-2',
+        configs: [
+          {
+            title: 'Other Component',
+            description: 'Other description',
+            targets: ['grafana/other/point'],
+            component: () => React.createElement('div', null, 'Other'),
+          },
+        ],
+      });
+
+      // Should NOT emit because the selected slice (same reference) didn't change
+      expect(subscribeCallback).toHaveBeenCalledTimes(2);
+      const secondValue = subscribeCallback.mock.calls[1][0];
+      expect(Object.is(firstValue, secondValue)).toBe(true);
+    });
+  });
 });
