@@ -24,7 +24,6 @@ export function emitDataRequestEvent(datasource: DataSourceApi) {
       eventName: MetaAnalyticsEventName.DataRequest,
       source: data.request.app,
       datasourceName: datasource.name,
-      datasourceId: datasource.id,
       datasourceUid: datasource.uid,
       datasourceType: datasource.type,
       dataSize: 0,
@@ -67,7 +66,6 @@ export function emitDataRequestEvent(datasource: DataSourceApi) {
 
     const dashboard = getDashboardSrv().getCurrent();
     if (dashboard) {
-      eventData.dashboardId = dashboard.id;
       eventData.dashboardName = dashboard.title;
       eventData.dashboardUid = dashboard.uid;
       eventData.folderName = dashboard.meta.folderTitle;
