@@ -32,6 +32,7 @@ import { getPartitionByValuesTransformRegistryItem } from './partitionByValues/P
 import { getPrepareTimeseriesTransformerRegistryItem } from './prepareTimeSeries/PrepareTimeSeriesEditor';
 import { getRegressionTransformerRegistryItem } from './regression/regressionEditor';
 import { getRowsToFieldsTransformRegistryItem } from './rowsToFields/RowsToFieldsTransformerEditor';
+import { getSmoothingTransformerRegistryItem } from './smoothing/smoothingEditor';
 import { getSpatialTransformRegistryItem } from './spatial/SpatialTransformerEditor';
 import { getTimeSeriesTableTransformRegistryItem } from './timeSeriesTable/TimeSeriesTableTransformEditor';
 
@@ -65,8 +66,9 @@ export const getStandardTransformers = (): TransformerRegistryItem[] => {
     getJoinByLabelsTransformRegistryItem(),
     getRegressionTransformerRegistryItem(),
     getPartitionByValuesTransformRegistryItem(),
-    ...(config.featureToggles.formatString ? [getFormatStringTransformerRegistryItem()] : []),
-    ...(config.featureToggles.groupToNestedTableTransformation ? [getGroupToNestedTableTransformRegistryItem()] : []),
+    getFormatStringTransformerRegistryItem(),
+    getGroupToNestedTableTransformRegistryItem(),
+    ...(config.featureToggles.smoothingTransformation ? [getSmoothingTransformerRegistryItem()] : []),
     getFormatTimeTransformerRegistryItem(),
     getTimeSeriesTableTransformRegistryItem(),
     getTransposeTransformerRegistryItem(),
