@@ -1,6 +1,6 @@
 //DOCS: https://prometheus.io/docs/alerting/latest/configuration/
 import { DataSourceJsonData, WithAccessControlMetadata } from '@grafana/data';
-import { IoK8SApimachineryPkgApisMetaV1ObjectMeta } from 'app/features/alerting/unified/openapi/receiversApi.gen';
+import { IoK8SApimachineryPkgApisMetaV1ObjectMeta } from 'app/features/alerting/unified/openapi/routesApi.gen';
 import { ExtraConfiguration } from 'app/features/alerting/unified/utils/alertmanager/extraConfigs';
 
 export const ROUTES_META_SYMBOL = Symbol('routes_metadata');
@@ -85,6 +85,10 @@ export type GrafanaManagedReceiverConfig = {
   // SecureSettings?: GrafanaManagedReceiverConfigSettings<boolean>;
   settings: GrafanaManagedReceiverConfigSettings;
   type: string;
+  /**
+   * Version of the integration (e.g. "v0" for Mimir legacy, "v1" for Grafana)
+   */
+  version?: string;
   /**
    * Name of the _receiver_, which in most cases will be the
    * same as the contact point's name. This should not be used, and is optional because the
@@ -104,7 +108,7 @@ export interface GrafanaManagedContactPoint {
   /** If parsed from k8s API, we'll have an ID property */
   id?: string;
   metadata?: IoK8SApimachineryPkgApisMetaV1ObjectMeta;
-  provisioned?: boolean;
+  provenance?: string;
   grafana_managed_receiver_configs?: GrafanaManagedReceiverConfig[];
 }
 
@@ -123,6 +127,7 @@ export type Receiver = GrafanaManagedContactPoint | AlertmanagerReceiver;
 export type ObjectMatcher = [name: string, operator: MatcherOperator, value: string];
 
 export type Route = {
+  name?: string;
   receiver?: string | null;
   group_by?: string[];
   continue?: boolean;
@@ -144,9 +149,10 @@ export type Route = {
   provenance?: string;
   /** this is used to add additional metadata to the routes without interfering with original route definition (symbols aren't iterable)  */
   [ROUTES_META_SYMBOL]?: {
-    provisioned?: boolean;
+    provenance?: string;
     resourceVersion?: string;
     name?: string;
+    metadata?: IoK8SApimachineryPkgApisMetaV1ObjectMeta;
   };
 };
 
