@@ -3,10 +3,12 @@ import userEvent from '@testing-library/user-event';
 import * as React from 'react';
 import { select, openMenu } from 'react-select-event';
 
+// eslint-disable-next-line no-restricted-imports
 import * as ui from '@grafana/ui';
 
-import createMockDatasource from '../../__mocks__/datasource';
-import { AzureMonitorQuery, AzureQueryType } from '../../types';
+import { AzureQueryType } from '../../dataquery.gen';
+import createMockDatasource from '../../mocks/datasource';
+import { AzureMonitorQuery } from '../../types/query';
 
 import VariableEditor from './VariableEditor';
 
@@ -22,18 +24,26 @@ jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
   getTemplateSrv: () => ({
     replace: (val: string) => {
+      if (val === '$ws') {
+        return '/subscriptions/def-456/resourceGroups/dev-3/providers/microsoft.operationalinsights/workspaces/la-workspace';
+      }
       return val;
     },
+    getVariables: () => [
+      { name: 'var1', current: { value: 'value1' } },
+      { name: 'var2', current: { value: 'value2' } },
+    ],
   }),
 }));
+
 const getResourceGroups = jest.fn().mockResolvedValue([{ resourceGroupURI: 'rg', resourceGroupName: 'rg', count: 1 }]);
 const getResourceNames = jest.fn().mockResolvedValue([
   {
-    id: 'foobarID',
+    id: '/subscriptions/subID/resourceGroups/resourceGroup/providers/foobarProvider/foobarType/foobar',
     name: 'foobar',
     subscriptionId: 'subID',
     resourceGroup: 'resourceGroup',
-    type: 'foobarType',
+    type: 'foobarProvider/foobarType',
     location: 'london',
   },
 ]);
@@ -77,10 +87,10 @@ describe('VariableEditor:', () => {
     const onChange = jest.fn();
     const legacyQuery = { ...defaultProps.query, queryType: AzureQueryType.GrafanaTemplateVariableFn };
     render(<VariableEditor {...defaultProps} onChange={onChange} query={legacyQuery} />);
-    await waitFor(() => screen.getByLabelText('select query type'));
-    expect(screen.getByLabelText('select query type')).toBeInTheDocument();
-    await userEvent.click(screen.getByLabelText('select query type'));
-    await select(screen.getByLabelText('select query type'), 'Grafana Query Function', {
+    await waitFor(() => screen.getByLabelText('Select query type'));
+    expect(screen.getByLabelText('Select query type')).toBeInTheDocument();
+    await userEvent.click(screen.getByLabelText('Select query type'));
+    await select(screen.getByLabelText('Select query type'), 'Grafana Query Function', {
       container: document.body,
     });
     expect(onChange).toHaveBeenCalledWith(
@@ -103,10 +113,10 @@ describe('VariableEditor:', () => {
       render(<VariableEditor {...defaultProps} onChange={onChange} />);
       await waitFor(() => screen.queryByTestId('mockeditor'));
       expect(screen.queryByTestId('mockeditor')).toBeInTheDocument();
-      await userEvent.type(screen.getByTestId('mockeditor'), '{backspace}');
+      await userEvent.type(screen.getByTestId('mockeditor'), '2');
       expect(onChange).toHaveBeenCalledWith({
         azureLogAnalytics: {
-          query: 'test quer',
+          query: 'test query2',
         },
         queryType: 'Azure Log Analytics',
         refId: 'A',
@@ -133,9 +143,9 @@ describe('VariableEditor:', () => {
       render(<VariableEditor {...ARGqueryProps} />);
       await waitFor(() => screen.queryByTestId('mockeditor'));
       await waitFor(() => screen.queryByLabelText('Subscriptions'));
+      expect(screen.queryByLabelText('Select query type')).toBeInTheDocument();
       expect(screen.queryByText('Resource Graph')).toBeInTheDocument();
       expect(screen.queryByLabelText('Select subscription')).not.toBeInTheDocument();
-      expect(screen.queryByLabelText('Select query type')).not.toBeInTheDocument();
       expect(screen.queryByLabelText('Select resource group')).not.toBeInTheDocument();
       expect(screen.queryByLabelText('Select namespace')).not.toBeInTheDocument();
       expect(screen.queryByLabelText('Select resource')).not.toBeInTheDocument();
@@ -227,7 +237,7 @@ describe('VariableEditor:', () => {
     it('should run the query if requesting subscriptions', async () => {
       const onChange = jest.fn();
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
-      await selectAndRerender('select query type', 'Subscriptions', onChange, rerender);
+      await selectAndRerender('Select query type', 'Subscriptions', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({ queryType: AzureQueryType.SubscriptionsQuery, refId: 'A' })
       );
@@ -238,8 +248,8 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Resource Groups', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select query type', 'Resource Groups', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.ResourceGroupsQuery,
@@ -254,9 +264,9 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Resource Groups', onChange, rerender);
+      await selectAndRerender('Select query type', 'Resource Groups', onChange, rerender);
       // Select a subscription
-      openMenu(screen.getByLabelText('select subscription'));
+      openMenu(screen.getByLabelText('Select subscription'));
       await waitFor(() => expect(screen.getByText('Primary Subscription')).toBeInTheDocument());
       await userEvent.click(screen.getByText('Template Variables'));
       // Simulate onChange behavior
@@ -272,8 +282,8 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Namespaces', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select query type', 'Namespaces', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.NamespacesQuery,
@@ -288,9 +298,9 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Resource Names', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
-      await selectAndRerender('select region', 'North Europe', onChange, rerender);
+      await selectAndRerender('Select query type', 'Resource Names', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select region', 'North Europe', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.ResourceNamesQuery,
@@ -306,11 +316,11 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Metric Names', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
-      await selectAndRerender('select resource group', 'rg', onChange, rerender);
-      await selectAndRerender('select namespace', 'foo/bar', onChange, rerender);
-      await selectAndRerender('select resource', 'foobar', onChange, rerender);
+      await selectAndRerender('Select query type', 'Metric Names', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select resource group', 'rg', onChange, rerender);
+      await selectAndRerender('Select namespace', 'foo/bar', onChange, rerender);
+      await selectAndRerender('Select resource', 'foobar', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.MetricNamesQuery,
@@ -329,7 +339,7 @@ describe('VariableEditor:', () => {
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
       // Select a new query type
-      await selectAndRerender('select query type', 'Subscriptions', onChange, rerender);
+      await selectAndRerender('Select query type', 'Subscriptions', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.SubscriptionsQuery,
@@ -347,8 +357,8 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Workspaces', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select query type', 'Workspaces', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.WorkspacesQuery,
@@ -363,8 +373,8 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Regions', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select query type', 'Regions', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.LocationsQuery,
@@ -379,11 +389,11 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Custom Namespaces', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
-      await selectAndRerender('select resource group', 'rg', onChange, rerender);
-      await selectAndRerender('select namespace', 'foo/bar', onChange, rerender);
-      await selectAndRerender('select resource', 'foobar', onChange, rerender);
+      await selectAndRerender('Select query type', 'Custom Namespaces', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select resource group', 'rg', onChange, rerender);
+      await selectAndRerender('Select namespace', 'foo/bar', onChange, rerender);
+      await selectAndRerender('Select resource', 'foobar', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.CustomNamespacesQuery,
@@ -401,12 +411,12 @@ describe('VariableEditor:', () => {
       const { rerender } = render(<VariableEditor {...defaultProps} onChange={onChange} />);
       // wait for initial load
       await waitFor(() => expect(screen.getByText('Logs')).toBeInTheDocument());
-      await selectAndRerender('select query type', 'Custom Metric Names', onChange, rerender);
-      await selectAndRerender('select subscription', 'Primary Subscription', onChange, rerender);
-      await selectAndRerender('select resource group', 'rg', onChange, rerender);
-      await selectAndRerender('select namespace', 'foo/bar', onChange, rerender);
-      await selectAndRerender('select resource', 'foobar', onChange, rerender);
-      await selectAndRerender('select custom namespace', 'foo/custom', onChange, rerender);
+      await selectAndRerender('Select query type', 'Custom Metric Names', onChange, rerender);
+      await selectAndRerender('Select subscription', 'Primary Subscription', onChange, rerender);
+      await selectAndRerender('Select resource group', 'rg', onChange, rerender);
+      await selectAndRerender('Select namespace', 'foo/bar', onChange, rerender);
+      await selectAndRerender('Select resource', 'foobar', onChange, rerender);
+      await selectAndRerender('Select custom namespace', 'foo/custom', onChange, rerender);
       expect(onChange).toHaveBeenCalledWith(
         expect.objectContaining({
           queryType: AzureQueryType.CustomMetricNamesQuery,
