@@ -3,8 +3,8 @@ import { EditorField } from '@grafana/plugin-ui';
 import { Select } from '@grafana/ui';
 
 import { SELECTORS } from '../constants';
+import { SLOQuery } from '../dataquery.gen';
 import CloudMonitoringDatasource from '../datasource';
-import { SLOQuery } from '../types/query';
 
 export interface Props {
   refId: string;
