@@ -25,20 +25,22 @@ import {
   TimeRange,
   TimeZone,
   toUtc,
-  urlUtil,
   LogSortOrderChangeEvent,
   LoadingState,
   rangeUtil,
+  transformDataFrame,
 } from '@grafana/data';
 import { Trans } from '@grafana/i18n';
 import { config, getAppEvents } from '@grafana/runtime';
 import { ScrollContainer, usePanelContext, useStyles2 } from '@grafana/ui';
+import { getDashboardSrv } from 'app/features/dashboard/services/DashboardSrv';
 import { getFieldLinksForExplore } from 'app/features/explore/utils/links';
 import { ControlledLogRows } from 'app/features/logs/components/ControlledLogRows';
 import { InfiniteScroll } from 'app/features/logs/components/InfiniteScroll';
 import { LogRowContextModal } from 'app/features/logs/components/log-context/LogRowContextModal';
 import { LogLineContext } from 'app/features/logs/components/panel/LogLineContext';
 import { LogList } from 'app/features/logs/components/panel/LogList';
+import { getLogsPanelState } from 'app/features/logs/components/panel/panelState/getLogsPanelState';
 import { PanelDataErrorView } from 'app/features/panel/components/PanelDataErrorView';
 import { combineResponses } from 'app/plugins/datasource/loki/mergeResponses';
 
@@ -135,12 +137,6 @@ interface LogsPanelProps extends PanelProps<Options> {
    * showLogAttributes?: boolean
    */
 }
-interface LogsPermalinkUrlState {
-  logs?: {
-    id?: string;
-  };
-}
-
 const noCommonLabels: Labels = {};
 
 export const LogsPanel = ({
@@ -177,6 +173,7 @@ export const LogsPanel = ({
     noInteractions,
     timestampResolution,
     showLogAttributes,
+    unwrappedColumns,
     ...options
   },
   height,
@@ -196,7 +193,7 @@ export const LogsPanel = ({
   const dataSourcesMap = useDatasourcesFromTargets(panelData.request?.targets);
   // Prevents the scroll position to change when new data from infinite scrolling is received
   const keepScrollPositionRef = useRef<null | 'infinite-scroll' | 'user'>(null);
-  let closeCallback = useRef<() => void>();
+  const closeCallback = useRef<(() => void) | undefined>(undefined);
   const { app, eventBus, onAddAdHocFilter } = usePanelContext();
 
   useEffect(() => {
@@ -464,7 +461,7 @@ export const LogsPanel = ({
 
   const loadMoreLogs = useCallback(
     async (scrollRange: AbsoluteTimeRange) => {
-      if (!data.request || !config.featureToggles.logsInfiniteScrolling || loadingRef.current) {
+      if (!data.request || loadingRef.current) {
         return;
       }
 
@@ -476,6 +473,10 @@ export const LogsPanel = ({
       let newSeries: DataFrame[] = [];
       try {
         newSeries = await requestMoreLogs(dataSourcesMap, panelData, scrollRange, timeZone, onNewLogsReceivedCallback);
+        const panel = getDashboardSrv().getCurrent()?.getPanelById(id);
+        if (panel?.transformations) {
+          newSeries = await lastValueFrom(transformDataFrame(panel?.transformations, newSeries));
+        }
       } catch (e) {
         console.error(e);
       } finally {
@@ -489,7 +490,7 @@ export const LogsPanel = ({
         series: newSeries,
       });
     },
-    [data.request, dataSourcesMap, onNewLogsReceived, panelData, timeZone]
+    [data.request, dataSourcesMap, id, onNewLogsReceived, panelData, timeZone]
   );
 
   const renderCommonLabels = () => (
@@ -566,9 +567,6 @@ export const LogsPanel = ({
           logLineMenuCustomItems={isLogLineMenuCustomItems(logLineMenuCustomItems) ? logLineMenuCustomItems : undefined}
           timeZone={timeZone}
           displayedFields={displayedFields}
-          onPermalinkClick={showPermaLink() ? onPermalinkClick : undefined}
-          onClickShowField={showField}
-          onClickHideField={hideField}
         />
       )}
       {config.featureToggles.newLogsPanel && (
@@ -576,7 +574,9 @@ export const LogsPanel = ({
           onMouseLeave={onLogContainerMouseLeave}
           className={style.logListContainer}
           style={height ? { minHeight: height } : undefined}
-          ref={(element: HTMLDivElement) => setScrollElement(element)}
+          ref={(element: HTMLDivElement) => {
+            setScrollElement(element);
+          }}
         >
           {deduplicatedRows.length > 0 && scrollElement && (
             <LogList
@@ -629,13 +629,18 @@ export const LogsPanel = ({
               timeRange={data.timeRange}
               timestampResolution={timestampResolution}
               timeZone={timeZone}
+              unwrappedColumns={unwrappedColumns}
               wrapLogMessage={wrapLogMessage}
             />
           )}
         </div>
       )}
       {!config.featureToggles.newLogsPanel && !showControls && (
-        <ScrollContainer ref={(scrollElement) => setScrollElement(scrollElement)}>
+        <ScrollContainer
+          ref={(scrollElement) => {
+            setScrollElement(scrollElement);
+          }}
+        >
           <div onMouseLeave={onLogContainerMouseLeave} className={style.container} ref={logsContainerRef}>
             {showCommonLabels && !isAscending && renderCommonLabels()}
             <InfiniteScroll
@@ -697,7 +702,9 @@ export const LogsPanel = ({
         <div onMouseLeave={onLogContainerMouseLeave} className={style.controlledLogsContainer}>
           {showCommonLabels && !isAscending && renderCommonLabels()}
           <ControlledLogRows
-            ref={(scrollElement: HTMLDivElement | null) => setScrollElement(scrollElement)}
+            ref={(scrollElement: HTMLDivElement | null) => {
+              setScrollElement(scrollElement);
+            }}
             visualisationType="logs"
             loading={infiniteScrolling}
             loadMoreLogs={enableInfiniteScrolling ? loadMoreLogs : undefined}
@@ -779,25 +786,6 @@ const getStyles = (theme: GrafanaTheme2) => ({
   }),
 });
 
-function getLogsPanelState(): LogsPermalinkUrlState | undefined {
-  const urlParams = urlUtil.getUrlSearchParams();
-  const panelStateEncoded = urlParams?.panelState;
-  if (
-    panelStateEncoded &&
-    Array.isArray(panelStateEncoded) &&
-    panelStateEncoded?.length > 0 &&
-    typeof panelStateEncoded[0] === 'string'
-  ) {
-    try {
-      return JSON.parse(panelStateEncoded[0]);
-    } catch (e) {
-      console.error('error parsing logsPanelState', e);
-    }
-  }
-
-  return undefined;
-}
-
 async function copyDashboardUrl(row: LogRowModel, rows: LogRowModel[], timeRange: TimeRange) {
   // this is an extra check, to be sure that we are not
   // creating permalinks for logs without an id-field.
