@@ -5,10 +5,9 @@ import SwaggerUI from 'swagger-ui-react';
 
 import { createTheme, monacoLanguageRegistry, SelectableValue } from '@grafana/data';
 import { Trans } from '@grafana/i18n';
-import { Stack, Select, UserIcon, UserView, Button } from '@grafana/ui';
+import { Icon, Stack, Select, UserIcon, UserView, Button } from '@grafana/ui';
 import { setMonacoEnv } from 'app/core/monacoEnv';
 import { ThemeProvider } from 'app/core/utils/ConfigProvider';
-import grafanaIconSvg from 'img/grafana_icon.svg';
 
 import { NamespaceContext, WrappedPlugins } from './plugins';
 
@@ -85,7 +84,7 @@ export const Page = () => {
         <NamespaceContext.Provider value={namespace.value}>
           <div style={{ backgroundColor: '#000', padding: '10px' }}>
             <Stack justifyContent={'space-between'}>
-              <img height="40" src={grafanaIconSvg} alt="Grafana" />
+              <Icon name="grafana" size="xxl" />
               <Select
                 options={urls.value}
                 isClearable={false /* TODO -- when we allow a landing page, this can be true */}
@@ -125,6 +124,7 @@ export const Page = () => {
               tryItOutEnabled={true}
               queryConfigEnabled={false}
               persistAuthorization={false}
+              displayOperationId
             />
           )}
           {!url?.value && <div>...{/** TODO, we can make an api docs loading page here */}</div>}
